@@ -1,12 +1,17 @@
 """Time-based One Time Password auth module."""
+
+from __future__ import annotations
+
 import asyncio
 from io import BytesIO
-from typing import Any, Dict, Optional, Tuple
+from typing import Any, cast
 
 import voluptuous as vol
 
 from homeassistant.auth.models import User
 from homeassistant.core import HomeAssistant
+from homeassistant.data_entry_flow import FlowResult
+from homeassistant.helpers.storage import Store
 
 from . import (
     MULTI_FACTOR_AUTH_MODULE_SCHEMA,
@@ -15,7 +20,7 @@ from . import (
     SetupFlow,
 )
 
-REQUIREMENTS = ["pyotp==2.3.0", "PyQRCode==1.2.1"]
+REQUIREMENTS = ["pyotp==2.8.0", "PyQRCode==1.2.1"]
 
 CONFIG_SCHEMA = MULTI_FACTOR_AUTH_MODULE_SCHEMA.extend({}, extra=vol.PREVENT_EXTRA)
 
@@ -32,7 +37,7 @@ DUMMY_SECRET = "FPPTH34D4E3MI2HG"
 
 def _generate_qr_code(data: str) -> str:
     """Generate a base64 PNG string represent QR Code image of data."""
-    import pyqrcode  # pylint: disable=import-outside-toplevel
+    import pyqrcode  # noqa: PLC0415
 
     qr_code = pyqrcode.create(data)
 
@@ -43,16 +48,18 @@ def _generate_qr_code(data: str) -> str:
             .decode("ascii")
             .replace("\n", "")
             .replace(
-                '<?xml version="1.0" encoding="UTF-8"?>'
-                '<svg xmlns="http://www.w3.org/2000/svg"',
+                (
+                    '<?xml version="1.0" encoding="UTF-8"?>'
+                    '<svg xmlns="http://www.w3.org/2000/svg"'
+                ),
                 "<svg",
             )
         )
 
 
-def _generate_secret_and_qr_code(username: str) -> Tuple[str, str, str]:
+def _generate_secret_and_qr_code(username: str) -> tuple[str, str, str]:
     """Generate a secret, url, and QR code."""
-    import pyotp  # pylint: disable=import-outside-toplevel
+    import pyotp  # noqa: PLC0415
 
     ota_secret = pyotp.random_base32()
     url = pyotp.totp.TOTP(ota_secret).provisioning_uri(
@@ -69,19 +76,19 @@ class TotpAuthModule(MultiFactorAuthModule):
     DEFAULT_TITLE = "Time-based One Time Password"
     MAX_RETRY_TIME = 5
 
-    def __init__(self, hass: HomeAssistant, config: Dict[str, Any]) -> None:
+    def __init__(self, hass: HomeAssistant, config: dict[str, Any]) -> None:
         """Initialize the user data store."""
         super().__init__(hass, config)
-        self._users: Optional[Dict[str, str]] = None
-        self._user_store = hass.helpers.storage.Store(
-            STORAGE_VERSION, STORAGE_KEY, private=True
+        self._users: dict[str, str] | None = None
+        self._user_store = Store[dict[str, dict[str, str]]](
+            hass, STORAGE_VERSION, STORAGE_KEY, private=True, atomic_writes=True
         )
         self._init_lock = asyncio.Lock()
 
     @property
     def input_schema(self) -> vol.Schema:
         """Validate login flow input data."""
-        return vol.Schema({INPUT_FIELD_CODE: str})
+        return vol.Schema({vol.Required(INPUT_FIELD_CODE): str})
 
     async def _async_load(self) -> None:
         """Load stored data."""
@@ -89,27 +96,25 @@ class TotpAuthModule(MultiFactorAuthModule):
             if self._users is not None:
                 return
 
-            data = await self._user_store.async_load()
-
-            if data is None:
-                data = {STORAGE_USERS: {}}
+            if (data := await self._user_store.async_load()) is None:
+                data = cast(dict[str, dict[str, str]], {STORAGE_USERS: {}})
 
             self._users = data.get(STORAGE_USERS, {})
 
     async def _async_save(self) -> None:
         """Save data."""
-        await self._user_store.async_save({STORAGE_USERS: self._users})
+        await self._user_store.async_save({STORAGE_USERS: self._users or {}})
 
-    def _add_ota_secret(self, user_id: str, secret: Optional[str] = None) -> str:
+    def _add_ota_secret(self, user_id: str, secret: str | None = None) -> str:
         """Create a ota_secret for user."""
-        import pyotp  # pylint: disable=import-outside-toplevel
+        import pyotp  # noqa: PLC0415
 
         ota_secret: str = secret or pyotp.random_base32()
 
-        self._users[user_id] = ota_secret  # type: ignore
+        self._users[user_id] = ota_secret  # type: ignore[index]
         return ota_secret
 
-    async def async_setup_flow(self, user_id: str) -> SetupFlow:
+    async def async_setup_flow(self, user_id: str) -> TotpSetupFlow:
         """Return a data entry flow handler for setup module.
 
         Mfa module should extend SetupFlow
@@ -135,7 +140,7 @@ class TotpAuthModule(MultiFactorAuthModule):
         if self._users is None:
             await self._async_load()
 
-        if self._users.pop(user_id, None):  # type: ignore
+        if self._users.pop(user_id, None):  # type: ignore[union-attr]
             await self._async_save()
 
     async def async_is_user_setup(self, user_id: str) -> bool:
@@ -143,9 +148,9 @@ class TotpAuthModule(MultiFactorAuthModule):
         if self._users is None:
             await self._async_load()
 
-        return user_id in self._users  # type: ignore
+        return user_id in self._users  # type: ignore[operator]
 
-    async def async_validate(self, user_id: str, user_input: Dict[str, Any]) -> bool:
+    async def async_validate(self, user_id: str, user_input: dict[str, Any]) -> bool:
         """Return True if validation passed."""
         if self._users is None:
             await self._async_load()
@@ -158,10 +163,9 @@ class TotpAuthModule(MultiFactorAuthModule):
 
     def _validate_2fa(self, user_id: str, code: str) -> bool:
         """Validate two factor authentication code."""
-        import pyotp  # pylint: disable=import-outside-toplevel
+        import pyotp  # noqa: PLC0415
 
-        ota_secret = self._users.get(user_id)  # type: ignore
-        if ota_secret is None:
+        if (ota_secret := self._users.get(user_id)) is None:  # type: ignore[union-attr]
             # even we cannot find user, we still do verify
             # to make timing the same as if user was found.
             pyotp.TOTP(DUMMY_SECRET).verify(code, valid_window=1)
@@ -170,32 +174,31 @@ class TotpAuthModule(MultiFactorAuthModule):
         return bool(pyotp.TOTP(ota_secret).verify(code, valid_window=1))
 
 
-class TotpSetupFlow(SetupFlow):
+class TotpSetupFlow(SetupFlow[TotpAuthModule]):
     """Handler for the setup flow."""
 
+    _ota_secret: str
+    _url: str
+    _image: str
+
     def __init__(
         self, auth_module: TotpAuthModule, setup_schema: vol.Schema, user: User
     ) -> None:
         """Initialize the setup flow."""
         super().__init__(auth_module, setup_schema, user.id)
-        # to fix typing complaint
-        self._auth_module: TotpAuthModule = auth_module
         self._user = user
-        self._ota_secret: Optional[str] = None
-        self._url = None  # type Optional[str]
-        self._image = None  # type Optional[str]
 
     async def async_step_init(
-        self, user_input: Optional[Dict[str, str]] = None
-    ) -> Dict[str, Any]:
+        self, user_input: dict[str, str] | None = None
+    ) -> FlowResult:
         """Handle the first step of setup flow.
 
         Return self.async_show_form(step_id='init') if user_input is None.
         Return self.async_create_entry(data={'result': result}) if finish.
         """
-        import pyotp  # pylint: disable=import-outside-toplevel
+        import pyotp  # noqa: PLC0415
 
-        errors: Dict[str, str] = {}
+        errors: dict[str, str] = {}
 
         if user_input:
             verified = await self.hass.async_add_executor_job(
@@ -205,20 +208,17 @@ class TotpSetupFlow(SetupFlow):
                 result = await self._auth_module.async_setup_user(
                     self._user_id, {"secret": self._ota_secret}
                 )
-                return self.async_create_entry(
-                    title=self._auth_module.name, data={"result": result}
-                )
+                return self.async_create_entry(data={"result": result})
 
             errors["base"] = "invalid_code"
 
         else:
-            hass = self._auth_module.hass
             (
                 self._ota_secret,
                 self._url,
                 self._image,
-            ) = await hass.async_add_executor_job(
-                _generate_secret_and_qr_code,  # type: ignore
+            ) = await self._auth_module.hass.async_add_executor_job(
+                _generate_secret_and_qr_code,
                 str(self._user.name),
             )
 
