@@ -1,12 +1,13 @@
 """Provides functionality to interact with climate devices."""
+
 from __future__ import annotations
 
-import asyncio
 from datetime import timedelta
 import functools as ft
 import logging
-from typing import TYPE_CHECKING, Any, Literal, final
+from typing import Any, Literal, final
 
+from propcache.api import cached_property
 import voluptuous as vol
 
 from homeassistant.config_entries import ConfigEntry
@@ -14,48 +15,22 @@ from homeassistant.const import (
     ATTR_TEMPERATURE,
     PRECISION_TENTHS,
     PRECISION_WHOLE,
+    SERVICE_TOGGLE,
     SERVICE_TURN_OFF,
     SERVICE_TURN_ON,
-    STATE_OFF,
-    STATE_ON,
     UnitOfTemperature,
 )
 from homeassistant.core import HomeAssistant, ServiceCall, callback
 from homeassistant.exceptions import ServiceValidationError
-import homeassistant.helpers.config_validation as cv
-from homeassistant.helpers.config_validation import (  # noqa: F401
-    PLATFORM_SCHEMA,
-    PLATFORM_SCHEMA_BASE,
-    make_entity_service_schema,
-)
-from homeassistant.helpers.deprecation import (
-    all_with_deprecated_constants,
-    check_if_deprecated_constant,
-    dir_with_deprecated_constants,
-)
+from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.entity import Entity, EntityDescription
 from homeassistant.helpers.entity_component import EntityComponent
-from homeassistant.helpers.entity_platform import EntityPlatform
 from homeassistant.helpers.temperature import display_temp as show_temp
 from homeassistant.helpers.typing import ConfigType
+from homeassistant.util.hass_dict import HassKey
 from homeassistant.util.unit_conversion import TemperatureConverter
 
 from .const import (  # noqa: F401
-    _DEPRECATED_HVAC_MODE_AUTO,
-    _DEPRECATED_HVAC_MODE_COOL,
-    _DEPRECATED_HVAC_MODE_DRY,
-    _DEPRECATED_HVAC_MODE_FAN_ONLY,
-    _DEPRECATED_HVAC_MODE_HEAT,
-    _DEPRECATED_HVAC_MODE_HEAT_COOL,
-    _DEPRECATED_HVAC_MODE_OFF,
-    _DEPRECATED_SUPPORT_AUX_HEAT,
-    _DEPRECATED_SUPPORT_FAN_MODE,
-    _DEPRECATED_SUPPORT_PRESET_MODE,
-    _DEPRECATED_SUPPORT_SWING_MODE,
-    _DEPRECATED_SUPPORT_TARGET_HUMIDITY,
-    _DEPRECATED_SUPPORT_TARGET_TEMPERATURE,
-    _DEPRECATED_SUPPORT_TARGET_TEMPERATURE_RANGE,
-    ATTR_AUX_HEAT,
     ATTR_CURRENT_HUMIDITY,
     ATTR_CURRENT_TEMPERATURE,
     ATTR_FAN_MODE,
@@ -70,6 +45,8 @@ from .const import (  # noqa: F401
     ATTR_MIN_TEMP,
     ATTR_PRESET_MODE,
     ATTR_PRESET_MODES,
+    ATTR_SWING_HORIZONTAL_MODE,
+    ATTR_SWING_HORIZONTAL_MODES,
     ATTR_SWING_MODE,
     ATTR_SWING_MODES,
     ATTR_TARGET_TEMP_HIGH,
@@ -87,6 +64,7 @@ from .const import (  # noqa: F401
     FAN_ON,
     FAN_TOP,
     HVAC_MODES,
+    INTENT_SET_TEMPERATURE,
     PRESET_ACTIVITY,
     PRESET_AWAY,
     PRESET_BOOST,
@@ -95,11 +73,11 @@ from .const import (  # noqa: F401
     PRESET_HOME,
     PRESET_NONE,
     PRESET_SLEEP,
-    SERVICE_SET_AUX_HEAT,
     SERVICE_SET_FAN_MODE,
     SERVICE_SET_HUMIDITY,
     SERVICE_SET_HVAC_MODE,
     SERVICE_SET_PRESET_MODE,
+    SERVICE_SET_SWING_HORIZONTAL_MODE,
     SERVICE_SET_SWING_MODE,
     SERVICE_SET_TEMPERATURE,
     SWING_BOTH,
@@ -112,29 +90,26 @@ from .const import (  # noqa: F401
     HVACMode,
 )
 
-if TYPE_CHECKING:
-    from functools import cached_property
-else:
-    from homeassistant.backports.functools import cached_property
+_LOGGER = logging.getLogger(__name__)
+
+DATA_COMPONENT: HassKey[EntityComponent[ClimateEntity]] = HassKey(DOMAIN)
+ENTITY_ID_FORMAT = DOMAIN + ".{}"
+PLATFORM_SCHEMA = cv.PLATFORM_SCHEMA
+PLATFORM_SCHEMA_BASE = cv.PLATFORM_SCHEMA_BASE
+SCAN_INTERVAL = timedelta(seconds=60)
 
 DEFAULT_MIN_TEMP = 7
 DEFAULT_MAX_TEMP = 35
 DEFAULT_MIN_HUMIDITY = 30
 DEFAULT_MAX_HUMIDITY = 99
 
-ENTITY_ID_FORMAT = DOMAIN + ".{}"
-SCAN_INTERVAL = timedelta(seconds=60)
-
 CONVERTIBLE_ATTRIBUTE = [ATTR_TEMPERATURE, ATTR_TARGET_TEMP_LOW, ATTR_TARGET_TEMP_HIGH]
 
-_LOGGER = logging.getLogger(__name__)
-
-
 SET_TEMPERATURE_SCHEMA = vol.All(
     cv.has_at_least_one_key(
         ATTR_TEMPERATURE, ATTR_TARGET_TEMP_HIGH, ATTR_TARGET_TEMP_LOW
     ),
-    make_entity_service_schema(
+    cv.make_entity_service_schema(
         {
             vol.Exclusive(ATTR_TEMPERATURE, "temperature"): vol.Coerce(float),
             vol.Inclusive(ATTR_TARGET_TEMP_HIGH, "temperature"): vol.Coerce(float),
@@ -149,27 +124,33 @@ SET_TEMPERATURE_SCHEMA = vol.All(
 
 async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     """Set up climate entities."""
-    component = hass.data[DOMAIN] = EntityComponent[ClimateEntity](
+    component = hass.data[DATA_COMPONENT] = EntityComponent[ClimateEntity](
         _LOGGER, DOMAIN, hass, SCAN_INTERVAL
     )
     await component.async_setup(config)
 
     component.async_register_entity_service(
         SERVICE_TURN_ON,
-        {},
+        None,
         "async_turn_on",
         [ClimateEntityFeature.TURN_ON],
     )
     component.async_register_entity_service(
         SERVICE_TURN_OFF,
-        {},
+        None,
         "async_turn_off",
         [ClimateEntityFeature.TURN_OFF],
     )
+    component.async_register_entity_service(
+        SERVICE_TOGGLE,
+        None,
+        "async_toggle",
+        [ClimateEntityFeature.TURN_OFF, ClimateEntityFeature.TURN_ON],
+    )
     component.async_register_entity_service(
         SERVICE_SET_HVAC_MODE,
         {vol.Required(ATTR_HVAC_MODE): vol.Coerce(HVACMode)},
-        "async_set_hvac_mode",
+        "async_handle_set_hvac_mode_service",
     )
     component.async_register_entity_service(
         SERVICE_SET_PRESET_MODE,
@@ -177,12 +158,6 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
         "async_handle_set_preset_mode_service",
         [ClimateEntityFeature.PRESET_MODE],
     )
-    component.async_register_entity_service(
-        SERVICE_SET_AUX_HEAT,
-        {vol.Required(ATTR_AUX_HEAT): cv.boolean},
-        async_service_aux_heat,
-        [ClimateEntityFeature.AUX_HEAT],
-    )
     component.async_register_entity_service(
         SERVICE_SET_TEMPERATURE,
         SET_TEMPERATURE_SCHEMA,
@@ -195,7 +170,7 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     component.async_register_entity_service(
         SERVICE_SET_HUMIDITY,
         {vol.Required(ATTR_HUMIDITY): vol.Coerce(int)},
-        "async_set_humidity",
+        async_service_humidity_set,
         [ClimateEntityFeature.TARGET_HUMIDITY],
     )
     component.async_register_entity_service(
@@ -210,20 +185,24 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
         "async_handle_set_swing_mode_service",
         [ClimateEntityFeature.SWING_MODE],
     )
+    component.async_register_entity_service(
+        SERVICE_SET_SWING_HORIZONTAL_MODE,
+        {vol.Required(ATTR_SWING_HORIZONTAL_MODE): cv.string},
+        "async_handle_set_swing_horizontal_mode_service",
+        [ClimateEntityFeature.SWING_HORIZONTAL_MODE],
+    )
 
     return True
 
 
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up a config entry."""
-    component: EntityComponent[ClimateEntity] = hass.data[DOMAIN]
-    return await component.async_setup_entry(entry)
+    return await hass.data[DATA_COMPONENT].async_setup_entry(entry)
 
 
 async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Unload a config entry."""
-    component: EntityComponent[ClimateEntity] = hass.data[DOMAIN]
-    return await component.async_unload_entry(entry)
+    return await hass.data[DATA_COMPONENT].async_unload_entry(entry)
 
 
 class ClimateEntityDescription(EntityDescription, frozen_or_thawed=True):
@@ -244,11 +223,12 @@ CACHED_PROPERTIES_WITH_ATTR_ = {
     "target_temperature_low",
     "preset_mode",
     "preset_modes",
-    "is_aux_heat",
     "fan_mode",
     "fan_modes",
     "swing_mode",
     "swing_modes",
+    "swing_horizontal_mode",
+    "swing_horizontal_modes",
     "supported_features",
     "min_temp",
     "max_temp",
@@ -282,10 +262,9 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
     _attr_hvac_action: HVACAction | None = None
     _attr_hvac_mode: HVACMode | None
     _attr_hvac_modes: list[HVACMode]
-    _attr_is_aux_heat: bool | None
-    _attr_max_humidity: int = DEFAULT_MAX_HUMIDITY
+    _attr_max_humidity: float = DEFAULT_MAX_HUMIDITY
     _attr_max_temp: float
-    _attr_min_humidity: int = DEFAULT_MIN_HUMIDITY
+    _attr_min_humidity: float = DEFAULT_MIN_HUMIDITY
     _attr_min_temp: float
     _attr_precision: float
     _attr_preset_mode: str | None
@@ -293,108 +272,15 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
     _attr_supported_features: ClimateEntityFeature = ClimateEntityFeature(0)
     _attr_swing_mode: str | None
     _attr_swing_modes: list[str] | None
-    _attr_target_humidity: int | None = None
+    _attr_swing_horizontal_mode: str | None
+    _attr_swing_horizontal_modes: list[str] | None
+    _attr_target_humidity: float | None = None
     _attr_target_temperature_high: float | None
     _attr_target_temperature_low: float | None
     _attr_target_temperature_step: float | None = None
     _attr_target_temperature: float | None = None
     _attr_temperature_unit: str
 
-    __mod_supported_features: ClimateEntityFeature = ClimateEntityFeature(0)
-    # Integrations should set `_enable_turn_on_off_backwards_compatibility` to False
-    # once migrated and set the feature flags TURN_ON/TURN_OFF as needed.
-    _enable_turn_on_off_backwards_compatibility: bool = True
-
-    def __getattribute__(self, __name: str) -> Any:
-        """Get attribute.
-
-        Modify return of `supported_features` to
-        include `_mod_supported_features` if attribute is set.
-        """
-        if __name != "supported_features":
-            return super().__getattribute__(__name)
-
-        # Convert the supported features to ClimateEntityFeature.
-        # Remove this compatibility shim in 2025.1 or later.
-        _supported_features = super().__getattribute__(__name)
-        if type(_supported_features) is int:  # noqa: E721
-            new_features = ClimateEntityFeature(_supported_features)
-            self._report_deprecated_supported_features_values(new_features)
-
-        # Add automatically calculated ClimateEntityFeature.TURN_OFF/TURN_ON to
-        # supported features and return it
-        return _supported_features | super().__getattribute__(
-            "_ClimateEntity__mod_supported_features"
-        )
-
-    @callback
-    def add_to_platform_start(
-        self,
-        hass: HomeAssistant,
-        platform: EntityPlatform,
-        parallel_updates: asyncio.Semaphore | None,
-    ) -> None:
-        """Start adding an entity to a platform."""
-        super().add_to_platform_start(hass, platform, parallel_updates)
-
-        def _report_turn_on_off(feature: str, method: str) -> None:
-            """Log warning not implemented turn on/off feature."""
-            report_issue = self._suggest_report_issue()
-            if feature.startswith("TURN"):
-                message = (
-                    "Entity %s (%s) does not set ClimateEntityFeature.%s"
-                    " but implements the %s method. Please %s"
-                )
-            else:
-                message = (
-                    "Entity %s (%s) implements HVACMode(s): %s and therefore implicitly"
-                    " supports the %s methods without setting the proper"
-                    " ClimateEntityFeature. Please %s"
-                )
-            _LOGGER.warning(
-                message,
-                self.entity_id,
-                type(self),
-                feature,
-                method,
-                report_issue,
-            )
-
-        # Adds ClimateEntityFeature.TURN_OFF/TURN_ON depending on service calls implemented
-        # This should be removed in 2025.1.
-        if self._enable_turn_on_off_backwards_compatibility is False:
-            # Return if integration has migrated already
-            return
-
-        if not self.supported_features & ClimateEntityFeature.TURN_OFF and (
-            type(self).async_turn_off is not ClimateEntity.async_turn_off
-            or type(self).turn_off is not ClimateEntity.turn_off
-        ):
-            # turn_off implicitly supported by implementing turn_off method
-            _report_turn_on_off("TURN_OFF", "turn_off")
-            self.__mod_supported_features |= (  # pylint: disable=unused-private-member
-                ClimateEntityFeature.TURN_OFF
-            )
-
-        if not self.supported_features & ClimateEntityFeature.TURN_ON and (
-            type(self).async_turn_on is not ClimateEntity.async_turn_on
-            or type(self).turn_on is not ClimateEntity.turn_on
-        ):
-            # turn_on implicitly supported by implementing turn_on method
-            _report_turn_on_off("TURN_ON", "turn_on")
-            self.__mod_supported_features |= (  # pylint: disable=unused-private-member
-                ClimateEntityFeature.TURN_ON
-            )
-
-        if (modes := self.hvac_modes) and len(modes) >= 2 and HVACMode.OFF in modes:
-            # turn_on/off implicitly supported by including more modes than 1 and one of these
-            # are HVACMode.OFF
-            _modes = [_mode for _mode in self.hvac_modes if _mode is not None]
-            _report_turn_on_off(", ".join(_modes or []), "turn_on/turn_off")
-            self.__mod_supported_features |= (  # pylint: disable=unused-private-member
-                ClimateEntityFeature.TURN_ON | ClimateEntityFeature.TURN_OFF
-            )
-
     @final
     @property
     def state(self) -> str | None:
@@ -446,6 +332,9 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
         if ClimateEntityFeature.SWING_MODE in supported_features:
             data[ATTR_SWING_MODES] = self.swing_modes
 
+        if ClimateEntityFeature.SWING_HORIZONTAL_MODE in supported_features:
+            data[ATTR_SWING_HORIZONTAL_MODES] = self.swing_horizontal_modes
+
         return data
 
     @final
@@ -497,8 +386,8 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
         if ClimateEntityFeature.SWING_MODE in supported_features:
             data[ATTR_SWING_MODE] = self.swing_mode
 
-        if ClimateEntityFeature.AUX_HEAT in supported_features:
-            data[ATTR_AUX_HEAT] = STATE_ON if self.is_aux_heat else STATE_OFF
+        if ClimateEntityFeature.SWING_HORIZONTAL_MODE in supported_features:
+            data[ATTR_SWING_HORIZONTAL_MODE] = self.swing_horizontal_mode
 
         return data
 
@@ -508,12 +397,12 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
         return self._attr_temperature_unit
 
     @cached_property
-    def current_humidity(self) -> int | None:
+    def current_humidity(self) -> float | None:
         """Return the current humidity."""
         return self._attr_current_humidity
 
     @cached_property
-    def target_humidity(self) -> int | None:
+    def target_humidity(self) -> float | None:
         """Return the humidity we try to reach."""
         return self._attr_target_humidity
 
@@ -579,14 +468,6 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
         """
         return self._attr_preset_modes
 
-    @cached_property
-    def is_aux_heat(self) -> bool | None:
-        """Return true if aux heater.
-
-        Requires ClimateEntityFeature.AUX_HEAT.
-        """
-        return self._attr_is_aux_heat
-
     @cached_property
     def fan_mode(self) -> str | None:
         """Return the fan setting.
@@ -619,27 +500,36 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
         """
         return self._attr_swing_modes
 
+    @cached_property
+    def swing_horizontal_mode(self) -> str | None:
+        """Return the horizontal swing setting.
+
+        Requires ClimateEntityFeature.SWING_HORIZONTAL_MODE.
+        """
+        return self._attr_swing_horizontal_mode
+
+    @cached_property
+    def swing_horizontal_modes(self) -> list[str] | None:
+        """Return the list of available horizontal swing modes.
+
+        Requires ClimateEntityFeature.SWING_HORIZONTAL_MODE.
+        """
+        return self._attr_swing_horizontal_modes
+
     @final
     @callback
     def _valid_mode_or_raise(
         self,
-        mode_type: Literal["preset", "swing", "fan"],
-        mode: str,
-        modes: list[str] | None,
+        mode_type: Literal["preset", "horizontal_swing", "swing", "fan", "hvac"],
+        mode: str | HVACMode,
+        modes: list[str] | list[HVACMode] | None,
     ) -> None:
         """Raise ServiceValidationError on invalid modes."""
         if modes and mode in modes:
             return
         modes_str: str = ", ".join(modes) if modes else ""
-        if mode_type == "preset":
-            translation_key = "not_valid_preset_mode"
-        elif mode_type == "swing":
-            translation_key = "not_valid_swing_mode"
-        elif mode_type == "fan":
-            translation_key = "not_valid_fan_mode"
+        translation_key = f"not_valid_{mode_type}_mode"
         raise ServiceValidationError(
-            f"The {mode_type}_mode {mode} is not a valid {mode_type}_mode:"
-            f" {modes_str}",
             translation_domain=DOMAIN,
             translation_key=translation_key,
             translation_placeholders={
@@ -650,7 +540,7 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
 
     def set_temperature(self, **kwargs: Any) -> None:
         """Set new target temperature."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     async def async_set_temperature(self, **kwargs: Any) -> None:
         """Set new target temperature."""
@@ -660,7 +550,7 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
 
     def set_humidity(self, humidity: int) -> None:
         """Set new target humidity."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     async def async_set_humidity(self, humidity: int) -> None:
         """Set new target humidity."""
@@ -674,15 +564,21 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
 
     def set_fan_mode(self, fan_mode: str) -> None:
         """Set new target fan mode."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     async def async_set_fan_mode(self, fan_mode: str) -> None:
         """Set new target fan mode."""
         await self.hass.async_add_executor_job(self.set_fan_mode, fan_mode)
 
+    @final
+    async def async_handle_set_hvac_mode_service(self, hvac_mode: HVACMode) -> None:
+        """Validate and set new preset mode."""
+        self._valid_mode_or_raise("hvac", hvac_mode, self.hvac_modes)
+        await self.async_set_hvac_mode(hvac_mode)
+
     def set_hvac_mode(self, hvac_mode: HVACMode) -> None:
         """Set new target hvac mode."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     async def async_set_hvac_mode(self, hvac_mode: HVACMode) -> None:
         """Set new target hvac mode."""
@@ -696,12 +592,32 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
 
     def set_swing_mode(self, swing_mode: str) -> None:
         """Set new target swing operation."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     async def async_set_swing_mode(self, swing_mode: str) -> None:
         """Set new target swing operation."""
         await self.hass.async_add_executor_job(self.set_swing_mode, swing_mode)
 
+    @final
+    async def async_handle_set_swing_horizontal_mode_service(
+        self, swing_horizontal_mode: str
+    ) -> None:
+        """Validate and set new horizontal swing mode."""
+        self._valid_mode_or_raise(
+            "horizontal_swing", swing_horizontal_mode, self.swing_horizontal_modes
+        )
+        await self.async_set_swing_horizontal_mode(swing_horizontal_mode)
+
+    def set_swing_horizontal_mode(self, swing_horizontal_mode: str) -> None:
+        """Set new target horizontal swing operation."""
+        raise NotImplementedError
+
+    async def async_set_swing_horizontal_mode(self, swing_horizontal_mode: str) -> None:
+        """Set new target horizontal swing operation."""
+        await self.hass.async_add_executor_job(
+            self.set_swing_horizontal_mode, swing_horizontal_mode
+        )
+
     @final
     async def async_handle_set_preset_mode_service(self, preset_mode: str) -> None:
         """Validate and set new preset mode."""
@@ -710,28 +626,12 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
 
     def set_preset_mode(self, preset_mode: str) -> None:
         """Set new preset mode."""
-        raise NotImplementedError()
+        raise NotImplementedError
 
     async def async_set_preset_mode(self, preset_mode: str) -> None:
         """Set new preset mode."""
         await self.hass.async_add_executor_job(self.set_preset_mode, preset_mode)
 
-    def turn_aux_heat_on(self) -> None:
-        """Turn auxiliary heater on."""
-        raise NotImplementedError()
-
-    async def async_turn_aux_heat_on(self) -> None:
-        """Turn auxiliary heater on."""
-        await self.hass.async_add_executor_job(self.turn_aux_heat_on)
-
-    def turn_aux_heat_off(self) -> None:
-        """Turn auxiliary heater off."""
-        raise NotImplementedError()
-
-    async def async_turn_aux_heat_off(self) -> None:
-        """Turn auxiliary heater off."""
-        await self.hass.async_add_executor_job(self.turn_aux_heat_off)
-
     def turn_on(self) -> None:
         """Turn the entity on."""
         raise NotImplementedError
@@ -756,7 +656,9 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
             if mode not in self.hvac_modes:
                 continue
             await self.async_set_hvac_mode(mode)
-            break
+            return
+
+        raise NotImplementedError
 
     def turn_off(self) -> None:
         """Turn the entity off."""
@@ -772,6 +674,26 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
         # Fake turn off
         if HVACMode.OFF in self.hvac_modes:
             await self.async_set_hvac_mode(HVACMode.OFF)
+            return
+
+        raise NotImplementedError
+
+    def toggle(self) -> None:
+        """Toggle the entity."""
+        raise NotImplementedError
+
+    async def async_toggle(self) -> None:
+        """Toggle the entity."""
+        # Forward to self.toggle if it's been overridden.
+        if type(self).toggle is not ClimateEntity.toggle:
+            await self.hass.async_add_executor_job(self.toggle)
+            return
+
+        # We assume that since turn_off is supported, HVACMode.OFF is as well.
+        if self.hvac_mode == HVACMode.OFF:
+            await self.async_turn_on()
+        else:
+            await self.async_turn_off()
 
     @cached_property
     def supported_features(self) -> ClimateEntityFeature:
@@ -797,49 +719,110 @@ class ClimateEntity(Entity, cached_properties=CACHED_PROPERTIES_WITH_ATTR_):
         return self._attr_max_temp
 
     @cached_property
-    def min_humidity(self) -> int:
+    def min_humidity(self) -> float:
         """Return the minimum humidity."""
         return self._attr_min_humidity
 
     @cached_property
-    def max_humidity(self) -> int:
+    def max_humidity(self) -> float:
         """Return the maximum humidity."""
         return self._attr_max_humidity
 
 
-async def async_service_aux_heat(
+async def async_service_humidity_set(
     entity: ClimateEntity, service_call: ServiceCall
 ) -> None:
-    """Handle aux heat service."""
-    if service_call.data[ATTR_AUX_HEAT]:
-        await entity.async_turn_aux_heat_on()
-    else:
-        await entity.async_turn_aux_heat_off()
+    """Handle set humidity service."""
+    humidity = service_call.data[ATTR_HUMIDITY]
+    min_humidity = entity.min_humidity
+    max_humidity = entity.max_humidity
+    _LOGGER.debug(
+        "Check valid humidity %d in range %d - %d",
+        humidity,
+        min_humidity,
+        max_humidity,
+    )
+    if humidity < min_humidity or humidity > max_humidity:
+        raise ServiceValidationError(
+            translation_domain=DOMAIN,
+            translation_key="humidity_out_of_range",
+            translation_placeholders={
+                "humidity": str(humidity),
+                "min_humidity": str(min_humidity),
+                "max_humidity": str(max_humidity),
+            },
+        )
+
+    await entity.async_set_humidity(humidity)
 
 
 async def async_service_temperature_set(
     entity: ClimateEntity, service_call: ServiceCall
 ) -> None:
     """Handle set temperature service."""
+    if (
+        ATTR_TEMPERATURE in service_call.data
+        and not entity.supported_features & ClimateEntityFeature.TARGET_TEMPERATURE
+    ):
+        raise ServiceValidationError(
+            translation_domain=DOMAIN,
+            translation_key="missing_target_temperature_entity_feature",
+        )
+    if (
+        ATTR_TARGET_TEMP_LOW in service_call.data
+        and not entity.supported_features
+        & ClimateEntityFeature.TARGET_TEMPERATURE_RANGE
+    ):
+        raise ServiceValidationError(
+            translation_domain=DOMAIN,
+            translation_key="missing_target_temperature_range_entity_feature",
+        )
+
     hass = entity.hass
-    kwargs = {}
+    kwargs: dict[str, Any] = {}
+    min_temp = entity.min_temp
+    max_temp = entity.max_temp
+    temp_unit = entity.temperature_unit
+
+    if (
+        (target_low_temp := service_call.data.get(ATTR_TARGET_TEMP_LOW))
+        and (target_high_temp := service_call.data.get(ATTR_TARGET_TEMP_HIGH))
+        and target_low_temp > target_high_temp
+    ):
+        # Ensure target_low_temp is not higher than target_high_temp.
+        raise ServiceValidationError(
+            translation_domain=DOMAIN,
+            translation_key="low_temp_higher_than_high_temp",
+        )
 
     for value, temp in service_call.data.items():
         if value in CONVERTIBLE_ATTRIBUTE:
-            kwargs[value] = TemperatureConverter.convert(
-                temp, hass.config.units.temperature_unit, entity.temperature_unit
+            kwargs[value] = check_temp = TemperatureConverter.convert(
+                temp, hass.config.units.temperature_unit, temp_unit
             )
+
+            _LOGGER.debug(
+                "Check valid temperature %d %s (%d %s) in range %d %s - %d %s",
+                check_temp,
+                entity.temperature_unit,
+                temp,
+                hass.config.units.temperature_unit,
+                min_temp,
+                temp_unit,
+                max_temp,
+                temp_unit,
+            )
+            if check_temp < min_temp or check_temp > max_temp:
+                raise ServiceValidationError(
+                    translation_domain=DOMAIN,
+                    translation_key="temp_out_of_range",
+                    translation_placeholders={
+                        "check_temp": str(check_temp),
+                        "min_temp": str(min_temp),
+                        "max_temp": str(max_temp),
+                    },
+                )
         else:
             kwargs[value] = temp
 
     await entity.async_set_temperature(**kwargs)
-
-
-# As we import deprecated constants from the const module, we need to add these two functions
-# otherwise this module will be logged for using deprecated constants and not the custom component
-# These can be removed if no deprecated constant are in this module anymore
-__getattr__ = ft.partial(check_if_deprecated_constant, module_globals=globals())
-__dir__ = ft.partial(
-    dir_with_deprecated_constants, module_globals_keys=[*globals().keys()]
-)
-__all__ = all_with_deprecated_constants(globals())
