@@ -1,28 +1,33 @@
 """Config flow for Coinbase integration."""
-import logging
 
-from coinbase.wallet.client import Client
+from __future__ import annotations
+
+import logging
+from typing import Any
+
+from coinbase.rest import RESTClient
+from coinbase.rest.rest_base import HTTPError
+from coinbase.wallet.client import Client as LegacyClient
 from coinbase.wallet.error import AuthenticationError
 import voluptuous as vol
 
-from homeassistant import config_entries, core, exceptions
-from homeassistant.const import CONF_API_KEY, CONF_API_TOKEN
-from homeassistant.core import callback
-import homeassistant.helpers.config_validation as cv
+from homeassistant.config_entries import ConfigFlow, ConfigFlowResult, OptionsFlow
+from homeassistant.const import CONF_API_KEY, CONF_API_TOKEN, CONF_API_VERSION
+from homeassistant.core import HomeAssistant, callback
+from homeassistant.exceptions import HomeAssistantError
+from homeassistant.helpers import config_validation as cv
 
-from . import get_accounts
+from . import CoinbaseConfigEntry, get_accounts
 from .const import (
+    ACCOUNT_IS_VAULT,
     API_ACCOUNT_CURRENCY,
+    API_DATA,
     API_RATES,
-    API_RESOURCE_TYPE,
-    API_TYPE_VAULT,
     CONF_CURRENCIES,
     CONF_EXCHANGE_BASE,
     CONF_EXCHANGE_PRECISION,
     CONF_EXCHANGE_PRECISION_DEFAULT,
     CONF_EXCHANGE_RATES,
-    CONF_OPTIONS,
-    CONF_YAML_API_TOKEN,
     DOMAIN,
     RATES,
     WALLETS,
@@ -40,23 +45,27 @@ STEP_USER_DATA_SCHEMA = vol.Schema(
 
 def get_user_from_client(api_key, api_token):
     """Get the user name from Coinbase API credentials."""
-    client = Client(api_key, api_token)
-    user = client.get_current_user()
-    return user
+    if "organizations" not in api_key:
+        client = LegacyClient(api_key, api_token)
+        return client.get_current_user()["name"]
+    client = RESTClient(api_key=api_key, api_secret=api_token)
+    return client.get_portfolios()["portfolios"][0]["name"]
 
 
-async def validate_api(hass: core.HomeAssistant, data):
+async def validate_api(hass: HomeAssistant, data):
     """Validate the credentials."""
 
     try:
         user = await hass.async_add_executor_job(
             get_user_from_client, data[CONF_API_KEY], data[CONF_API_TOKEN]
         )
-    except AuthenticationError as error:
-        if "api key" in str(error):
+    except (AuthenticationError, HTTPError) as error:
+        if "api key" in str(error) or " 401 Client Error" in str(error):
             _LOGGER.debug("Coinbase rejected API credentials due to an invalid API key")
             raise InvalidKey from error
-        if "invalid signature" in str(error):
+        if "invalid signature" in str(
+            error
+        ) or "'Could not deserialize key data" in str(error):
             _LOGGER.debug(
                 "Coinbase rejected API credentials due to an invalid API secret"
             )
@@ -65,25 +74,31 @@ async def validate_api(hass: core.HomeAssistant, data):
         raise InvalidAuth from error
     except ConnectionError as error:
         raise CannotConnect from error
-
-    return {"title": user["name"]}
+    api_version = "v3" if "organizations" in data[CONF_API_KEY] else "v2"
+    return {"title": user, "api_version": api_version}
 
 
 async def validate_options(
-    hass: core.HomeAssistant, config_entry: config_entries.ConfigEntry, options
+    hass: HomeAssistant, config_entry: CoinbaseConfigEntry, options
 ):
     """Validate the requested resources are provided by API."""
 
-    client = hass.data[DOMAIN][config_entry.entry_id].client
+    client = config_entry.runtime_data.client
 
-    accounts = await hass.async_add_executor_job(get_accounts, client)
+    accounts = await hass.async_add_executor_job(
+        get_accounts, client, config_entry.data.get("api_version", "v2")
+    )
 
     accounts_currencies = [
         account[API_ACCOUNT_CURRENCY]
         for account in accounts
-        if account[API_RESOURCE_TYPE] != API_TYPE_VAULT
+        if not account[ACCOUNT_IS_VAULT]
     ]
-    available_rates = await hass.async_add_executor_job(client.get_exchange_rates)
+    if config_entry.data.get("api_version", "v2") == "v2":
+        available_rates = await hass.async_add_executor_job(client.get_exchange_rates)
+    else:
+        resp = await hass.async_add_executor_job(client.get, "/v2/exchange-rates")
+        available_rates = resp[API_DATA]
     if CONF_CURRENCIES in options:
         for currency in options[CONF_CURRENCIES]:
             if currency not in accounts_currencies:
@@ -97,14 +112,16 @@ async def validate_options(
     return True
 
 
-class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
+class CoinbaseConfigFlow(ConfigFlow, domain=DOMAIN):
     """Handle a config flow for Coinbase."""
 
     VERSION = 1
 
-    async def async_step_user(self, user_input=None):
+    async def async_step_user(
+        self, user_input: dict[str, str] | None = None
+    ) -> ConfigFlowResult:
         """Handle the initial step."""
-        errors = {}
+        errors: dict[str, str] = {}
         if user_input is None:
             return self.async_show_form(
                 step_id="user", data_schema=STEP_USER_DATA_SCHEMA, errors=errors
@@ -112,11 +129,6 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
 
         self._async_abort_entries_match({CONF_API_KEY: user_input[CONF_API_KEY]})
 
-        options = {}
-
-        if CONF_OPTIONS in user_input:
-            options = user_input.pop(CONF_OPTIONS)
-
         try:
             info = await validate_api(self.hass, user_input)
         except CannotConnect:
@@ -127,52 +139,31 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             errors["base"] = "invalid_auth_secret"
         except InvalidAuth:
             errors["base"] = "invalid_auth"
-        except Exception:  # pylint: disable=broad-except
+        except Exception:
             _LOGGER.exception("Unexpected exception")
             errors["base"] = "unknown"
         else:
-            return self.async_create_entry(
-                title=info["title"], data=user_input, options=options
-            )
+            user_input[CONF_API_VERSION] = info["api_version"]
+            return self.async_create_entry(title=info["title"], data=user_input)
         return self.async_show_form(
             step_id="user", data_schema=STEP_USER_DATA_SCHEMA, errors=errors
         )
 
-    async def async_step_import(self, config):
-        """Handle import of Coinbase config from YAML."""
-
-        cleaned_data = {
-            CONF_API_KEY: config[CONF_API_KEY],
-            CONF_API_TOKEN: config[CONF_YAML_API_TOKEN],
-        }
-        cleaned_data[CONF_OPTIONS] = {
-            CONF_CURRENCIES: [],
-            CONF_EXCHANGE_RATES: [],
-        }
-        if CONF_CURRENCIES in config:
-            cleaned_data[CONF_OPTIONS][CONF_CURRENCIES] = config[CONF_CURRENCIES]
-        if CONF_EXCHANGE_RATES in config:
-            cleaned_data[CONF_OPTIONS][CONF_EXCHANGE_RATES] = config[
-                CONF_EXCHANGE_RATES
-            ]
-
-        return await self.async_step_user(user_input=cleaned_data)
-
     @staticmethod
     @callback
-    def async_get_options_flow(config_entry):
+    def async_get_options_flow(
+        config_entry: CoinbaseConfigEntry,
+    ) -> OptionsFlowHandler:
         """Get the options flow for this handler."""
-        return OptionsFlowHandler(config_entry)
+        return OptionsFlowHandler()
 
 
-class OptionsFlowHandler(config_entries.OptionsFlow):
+class OptionsFlowHandler(OptionsFlow):
     """Handle a option flow for Coinbase."""
 
-    def __init__(self, config_entry: config_entries.ConfigEntry) -> None:
-        """Initialize options flow."""
-        self.config_entry = config_entry
-
-    async def async_step_init(self, user_input=None):
+    async def async_step_init(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Manage the options."""
 
         errors = {}
@@ -203,7 +194,7 @@ class OptionsFlowHandler(config_entries.OptionsFlow):
                 errors["base"] = "currency_unavailable"
             except ExchangeRateUnavailable:
                 errors["base"] = "exchange_rate_unavailable"
-            except Exception:  # pylint: disable=broad-except
+            except Exception:
                 _LOGGER.exception("Unexpected exception")
                 errors["base"] = "unknown"
             else:
@@ -234,29 +225,29 @@ class OptionsFlowHandler(config_entries.OptionsFlow):
         )
 
 
-class CannotConnect(exceptions.HomeAssistantError):
+class CannotConnect(HomeAssistantError):
     """Error to indicate we cannot connect."""
 
 
-class InvalidAuth(exceptions.HomeAssistantError):
+class InvalidAuth(HomeAssistantError):
     """Error to indicate there is invalid auth."""
 
 
-class InvalidSecret(exceptions.HomeAssistantError):
+class InvalidSecret(HomeAssistantError):
     """Error to indicate auth failed due to invalid secret."""
 
 
-class InvalidKey(exceptions.HomeAssistantError):
+class InvalidKey(HomeAssistantError):
     """Error to indicate auth failed due to invalid key."""
 
 
-class AlreadyConfigured(exceptions.HomeAssistantError):
+class AlreadyConfigured(HomeAssistantError):
     """Error to indicate Coinbase API Key is already configured."""
 
 
-class CurrencyUnavailable(exceptions.HomeAssistantError):
+class CurrencyUnavailable(HomeAssistantError):
     """Error to indicate the requested currency resource is not provided by the API."""
 
 
-class ExchangeRateUnavailable(exceptions.HomeAssistantError):
+class ExchangeRateUnavailable(HomeAssistantError):
     """Error to indicate the requested exchange rate resource is not provided by the API."""
