@@ -1,15 +1,14 @@
 """Diagnostics support for discovergy."""
+
 from __future__ import annotations
 
 from dataclasses import asdict
 from typing import Any
 
 from homeassistant.components.diagnostics import async_redact_data
-from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 
-from .const import DOMAIN
-from .coordinator import DiscovergyUpdateCoordinator
+from .coordinator import DiscovergyConfigEntry
 
 TO_REDACT_METER = {
     "serial_number",
@@ -21,14 +20,13 @@ TO_REDACT_METER = {
 
 
 async def async_get_config_entry_diagnostics(
-    hass: HomeAssistant, entry: ConfigEntry
+    hass: HomeAssistant, entry: DiscovergyConfigEntry
 ) -> dict[str, Any]:
     """Return diagnostics for a config entry."""
     flattened_meter: list[dict] = []
     last_readings: dict[str, dict] = {}
-    coordinators: list[DiscovergyUpdateCoordinator] = hass.data[DOMAIN][entry.entry_id]
 
-    for coordinator in coordinators:
+    for coordinator in entry.runtime_data:
         # make a dict of meter data and redact some data
         flattened_meter.append(
             async_redact_data(asdict(coordinator.meter), TO_REDACT_METER)
