@@ -1,4 +1,5 @@
 """Switch representing the shutoff valve for the Flo by Moen integration."""
+
 from __future__ import annotations
 
 from typing import Any
@@ -7,13 +8,11 @@ from aioflo.location import SLEEP_MINUTE_OPTIONS, SYSTEM_MODE_HOME, SYSTEM_REVER
 import voluptuous as vol
 
 from homeassistant.components.switch import SwitchEntity
-from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import entity_platform
-from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.entity_platform import AddConfigEntryEntitiesCallback
 
-from .const import DOMAIN as FLO_DOMAIN
-from .device import FloDeviceDataUpdateCoordinator
+from .coordinator import FloConfigEntry, FloDeviceDataUpdateCoordinator
 from .entity import FloEntity
 
 ATTR_REVERT_TO_MODE = "revert_to_mode"
@@ -26,29 +25,26 @@ SERVICE_RUN_HEALTH_TEST = "run_health_test"
 
 async def async_setup_entry(
     hass: HomeAssistant,
-    config_entry: ConfigEntry,
-    async_add_entities: AddEntitiesCallback,
+    config_entry: FloConfigEntry,
+    async_add_entities: AddConfigEntryEntitiesCallback,
 ) -> None:
     """Set up the Flo switches from config entry."""
-    devices: list[FloDeviceDataUpdateCoordinator] = hass.data[FLO_DOMAIN][
-        config_entry.entry_id
-    ]["devices"]
-    entities = []
-    for device in devices:
-        if device.device_type != "puck_oem":
-            entities.append(FloSwitch(device))
-    async_add_entities(entities)
+    devices = config_entry.runtime_data.devices
+
+    async_add_entities(
+        [FloSwitch(device) for device in devices if device.device_type != "puck_oem"]
+    )
 
     platform = entity_platform.async_get_current_platform()
 
     platform.async_register_entity_service(
-        SERVICE_SET_AWAY_MODE, {}, "async_set_mode_away"
+        SERVICE_SET_AWAY_MODE, None, "async_set_mode_away"
     )
     platform.async_register_entity_service(
-        SERVICE_SET_HOME_MODE, {}, "async_set_mode_home"
+        SERVICE_SET_HOME_MODE, None, "async_set_mode_home"
     )
     platform.async_register_entity_service(
-        SERVICE_RUN_HEALTH_TEST, {}, "async_run_health_test"
+        SERVICE_RUN_HEALTH_TEST, None, "async_run_health_test"
     )
     platform.async_register_entity_service(
         SERVICE_SET_SLEEP_MODE,
@@ -75,13 +71,6 @@ class FloSwitch(FloEntity, SwitchEntity):
         super().__init__("shutoff_valve", device)
         self._attr_is_on = device.last_known_valve_state == "open"
 
-    @property
-    def icon(self):
-        """Return the icon to use for the valve."""
-        if self.is_on:
-            return "mdi:valve-open"
-        return "mdi:valve-closed"
-
     async def async_turn_on(self, **kwargs: Any) -> None:
         """Open the valve."""
         await self._device.api_client.device.open_valve(self._device.id)
