@@ -75,8 +75,6 @@ async def async_setup_entry(hass: HomeAssistant, entry: FritzConfigEntry) -> boo
     if FRITZ_DATA_KEY not in hass.data:
         hass.data[FRITZ_DATA_KEY] = FritzData()
 
-    entry.async_on_unload(entry.add_update_listener(update_listener))
-
     # Load the other platforms like switch
     await hass.config_entries.async_forward_entry_setups(entry, PLATFORMS)
 
@@ -94,9 +92,3 @@ async def async_unload_entry(hass: HomeAssistant, entry: FritzConfigEntry) -> bo
         hass.data.pop(FRITZ_DATA_KEY)
 
     return await hass.config_entries.async_unload_platforms(entry, PLATFORMS)
-
-
-async def update_listener(hass: HomeAssistant, entry: FritzConfigEntry) -> None:
-    """Update when config_entry options update."""
-    if entry.options:
-        await hass.config_entries.async_reload(entry.entry_id)
