@@ -1,12 +1,18 @@
 """Config flow for Elexa Guardian integration."""
+
+from __future__ import annotations
+
+from typing import Any
+
 from aioguardian import Client
 from aioguardian.errors import GuardianError
 import voluptuous as vol
 
-from homeassistant import config_entries, core
-from homeassistant.components.dhcp import IP_ADDRESS
+from homeassistant.config_entries import ConfigFlow, ConfigFlowResult
 from homeassistant.const import CONF_IP_ADDRESS, CONF_PORT
-from homeassistant.core import callback
+from homeassistant.core import HomeAssistant, callback
+from homeassistant.helpers.service_info.dhcp import DhcpServiceInfo
+from homeassistant.helpers.service_info.zeroconf import ZeroconfServiceInfo
 
 from .const import CONF_UID, DOMAIN, LOGGER
 
@@ -23,18 +29,18 @@ UNIQUE_ID = "guardian_{0}"
 
 
 @callback
-def async_get_pin_from_discovery_hostname(hostname):
+def async_get_pin_from_discovery_hostname(hostname: str) -> str:
     """Get the device's 4-digit PIN from its zeroconf-discovered hostname."""
     return hostname.split(".")[0].split("-")[1]
 
 
 @callback
-def async_get_pin_from_uid(uid):
+def async_get_pin_from_uid(uid: str) -> str:
     """Get the device's 4-digit PIN from its UID."""
     return uid[-4:]
 
 
-async def validate_input(hass: core.HomeAssistant, data):
+async def validate_input(hass: HomeAssistant, data: dict[str, Any]) -> dict[str, Any]:
     """Validate the user input allows us to connect.
 
     Data has the keys from DATA_SCHEMA with values provided by the user.
@@ -47,26 +53,31 @@ async def validate_input(hass: core.HomeAssistant, data):
     }
 
 
-class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
+class GuardianConfigFlow(ConfigFlow, domain=DOMAIN):
     """Handle a config flow for Elexa Guardian."""
 
     VERSION = 1
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Initialize."""
-        self.discovery_info = {}
+        self.discovery_info: dict[str, Any] = {}
 
-    async def _async_set_unique_id(self, pin):
+    async def _async_set_unique_id(self, pin: str) -> None:
         """Set the config entry's unique ID (based on the device's 4-digit PIN)."""
         await self.async_set_unique_id(UNIQUE_ID.format(pin))
         if self.discovery_info:
             self._abort_if_unique_id_configured(
                 updates={CONF_IP_ADDRESS: self.discovery_info[CONF_IP_ADDRESS]}
             )
+            self._async_abort_entries_match(
+                {CONF_IP_ADDRESS: self.discovery_info[CONF_IP_ADDRESS]}
+            )
         else:
             self._abort_if_unique_id_configured()
 
-    async def async_step_user(self, user_input=None):
+    async def async_step_user(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Handle configuration via the UI."""
         if user_input is None:
             return self.async_show_form(
@@ -90,36 +101,34 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             title=info[CONF_UID], data={CONF_UID: info["uid"], **user_input}
         )
 
-    async def async_step_dhcp(self, discovery_info):
+    async def async_step_dhcp(
+        self, discovery_info: DhcpServiceInfo
+    ) -> ConfigFlowResult:
         """Handle the configuration via dhcp."""
         self.discovery_info = {
-            CONF_IP_ADDRESS: discovery_info[IP_ADDRESS],
+            CONF_IP_ADDRESS: discovery_info.ip,
             CONF_PORT: DEFAULT_PORT,
         }
-        return await self._async_handle_discovery()
-
-    async def async_step_zeroconf(self, discovery_info):
-        """Handle the configuration via zeroconf."""
-        self.discovery_info = {
-            CONF_IP_ADDRESS: discovery_info["host"],
-            CONF_PORT: discovery_info["port"],
-        }
-        pin = async_get_pin_from_discovery_hostname(discovery_info["hostname"])
-        await self._async_set_unique_id(pin)
-        return await self._async_handle_discovery()
-
-    async def _async_handle_discovery(self):
-        """Handle any discovery."""
-        self.context[CONF_IP_ADDRESS] = self.discovery_info[CONF_IP_ADDRESS]
-        if any(
-            self.context[CONF_IP_ADDRESS] == flow["context"][CONF_IP_ADDRESS]
-            for flow in self._async_in_progress()
-        ):
-            return self.async_abort(reason="already_in_progress")
-
+        await self._async_set_unique_id(
+            async_get_pin_from_uid(discovery_info.macaddress.replace(":", "").upper())
+        )
         return await self.async_step_discovery_confirm()
 
-    async def async_step_discovery_confirm(self, user_input=None):
+    async def async_step_zeroconf(
+        self, discovery_info: ZeroconfServiceInfo
+    ) -> ConfigFlowResult:
+        """Handle the configuration via zeroconf."""
+        self.discovery_info = {
+            CONF_IP_ADDRESS: discovery_info.host,
+            CONF_PORT: discovery_info.port,
+        }
+        pin = async_get_pin_from_discovery_hostname(discovery_info.hostname)
+        await self._async_set_unique_id(pin)
+        return await self.async_step_discovery_confirm()
+
+    async def async_step_discovery_confirm(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Finish the configuration via any discovery."""
         if user_input is None:
             self._set_confirm_only()
