@@ -1,10 +1,13 @@
 """Provides device automations for Philips Hue events in V1 bridge/api."""
+
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 import voluptuous as vol
 
-from homeassistant.components.device_automation import DEVICE_TRIGGER_BASE_SCHEMA
-from homeassistant.components.device_automation.exceptions import (
+from homeassistant.components.device_automation import (
+    DEVICE_TRIGGER_BASE_SCHEMA,
     InvalidDeviceAutomationConfig,
 )
 from homeassistant.components.homeassistant.triggers import event as event_trigger
@@ -24,7 +27,7 @@ from homeassistant.helpers.typing import ConfigType
 from ..const import ATTR_HUE_EVENT, CONF_SUBTYPE, DOMAIN
 
 if TYPE_CHECKING:
-    from ..bridge import HueBridge
+    from ..bridge import HueBridge, HueConfigEntry
 
 TRIGGER_SCHEMA = DEVICE_TRIGGER_BASE_SCHEMA.extend(
     {vol.Required(CONF_TYPE): str, vol.Required(CONF_SUBTYPE): str}
@@ -108,8 +111,9 @@ REMOTES: dict[str, dict[tuple[str, str], dict[str, int]]] = {
 
 def _get_hue_event_from_device_id(hass, device_id):
     """Resolve hue event from device id."""
-    for bridge in hass.data.get(DOMAIN, {}).values():
-        for hue_event in bridge.sensor_manager.current_events.values():
+    entries: list[HueConfigEntry] = hass.config_entries.async_loaded_entries(DOMAIN)
+    for entry in entries:
+        for hue_event in entry.runtime_data.sensor_manager.current_events.values():
             if device_id == hue_event.device_registry_id:
                 return hue_event
 
@@ -117,7 +121,7 @@ def _get_hue_event_from_device_id(hass, device_id):
 
 
 async def async_validate_trigger_config(
-    bridge: "HueBridge", device_entry: DeviceEntry, config: ConfigType
+    bridge: HueBridge, device_entry: DeviceEntry, config: ConfigType
 ) -> ConfigType:
     """Validate config."""
     config = TRIGGER_SCHEMA(config)
@@ -142,7 +146,7 @@ async def async_validate_trigger_config(
 
 
 async def async_attach_trigger(
-    bridge: "HueBridge",
+    bridge: HueBridge,
     device_entry: DeviceEntry,
     config: ConfigType,
     action: TriggerActionType,
@@ -173,9 +177,7 @@ async def async_attach_trigger(
 
 
 @callback
-def async_get_triggers(
-    bridge: "HueBridge", device: DeviceEntry
-) -> list[dict[str, str]]:
+def async_get_triggers(bridge: HueBridge, device: DeviceEntry) -> list[dict[str, str]]:
     """Return device triggers for device on `v1` bridge.
 
     Make sure device is a supported remote model.
