@@ -1,4 +1,5 @@
 """Support for MQTT lights."""
+
 from __future__ import annotations
 
 from collections.abc import Callable
@@ -8,20 +9,25 @@ from typing import Any, cast
 import voluptuous as vol
 
 from homeassistant.components.light import (
+    _DEPRECATED_ATTR_COLOR_TEMP,
+    _DEPRECATED_ATTR_MAX_MIREDS,
+    _DEPRECATED_ATTR_MIN_MIREDS,
     ATTR_BRIGHTNESS,
     ATTR_COLOR_MODE,
-    ATTR_COLOR_TEMP,
+    ATTR_COLOR_TEMP_KELVIN,
     ATTR_EFFECT,
     ATTR_EFFECT_LIST,
     ATTR_HS_COLOR,
-    ATTR_MAX_MIREDS,
-    ATTR_MIN_MIREDS,
+    ATTR_MAX_COLOR_TEMP_KELVIN,
+    ATTR_MIN_COLOR_TEMP_KELVIN,
     ATTR_RGB_COLOR,
     ATTR_RGBW_COLOR,
     ATTR_RGBWW_COLOR,
     ATTR_SUPPORTED_COLOR_MODES,
     ATTR_WHITE,
     ATTR_XY_COLOR,
+    DEFAULT_MAX_KELVIN,
+    DEFAULT_MIN_KELVIN,
     ENTITY_ID_FORMAT,
     ColorMode,
     LightEntity,
@@ -36,91 +42,100 @@ from homeassistant.const import (
     STATE_ON,
 )
 from homeassistant.core import callback
-import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.restore_state import RestoreEntity
-from homeassistant.helpers.typing import ConfigType
-import homeassistant.util.color as color_util
+from homeassistant.helpers.service_info.mqtt import ReceivePayloadType
+from homeassistant.helpers.typing import ConfigType, VolSchemaType
+from homeassistant.util import color as color_util
 
 from .. import subscription
 from ..config import MQTT_RW_SCHEMA
 from ..const import (
+    CONF_BRIGHTNESS_COMMAND_TEMPLATE,
+    CONF_BRIGHTNESS_COMMAND_TOPIC,
+    CONF_BRIGHTNESS_SCALE,
+    CONF_BRIGHTNESS_STATE_TOPIC,
+    CONF_BRIGHTNESS_VALUE_TEMPLATE,
+    CONF_COLOR_MODE_STATE_TOPIC,
+    CONF_COLOR_MODE_VALUE_TEMPLATE,
+    CONF_COLOR_TEMP_COMMAND_TEMPLATE,
+    CONF_COLOR_TEMP_COMMAND_TOPIC,
+    CONF_COLOR_TEMP_KELVIN,
+    CONF_COLOR_TEMP_STATE_TOPIC,
+    CONF_COLOR_TEMP_VALUE_TEMPLATE,
     CONF_COMMAND_TOPIC,
-    CONF_ENCODING,
-    CONF_QOS,
-    CONF_RETAIN,
+    CONF_EFFECT_COMMAND_TEMPLATE,
+    CONF_EFFECT_COMMAND_TOPIC,
+    CONF_EFFECT_LIST,
+    CONF_EFFECT_STATE_TOPIC,
+    CONF_EFFECT_VALUE_TEMPLATE,
+    CONF_HS_COMMAND_TEMPLATE,
+    CONF_HS_COMMAND_TOPIC,
+    CONF_HS_STATE_TOPIC,
+    CONF_HS_VALUE_TEMPLATE,
+    CONF_MAX_KELVIN,
+    CONF_MAX_MIREDS,
+    CONF_MIN_KELVIN,
+    CONF_MIN_MIREDS,
+    CONF_ON_COMMAND_TYPE,
+    CONF_RGB_COMMAND_TEMPLATE,
+    CONF_RGB_COMMAND_TOPIC,
+    CONF_RGB_STATE_TOPIC,
+    CONF_RGB_VALUE_TEMPLATE,
+    CONF_RGBW_COMMAND_TEMPLATE,
+    CONF_RGBW_COMMAND_TOPIC,
+    CONF_RGBW_STATE_TOPIC,
+    CONF_RGBW_VALUE_TEMPLATE,
+    CONF_RGBWW_COMMAND_TEMPLATE,
+    CONF_RGBWW_COMMAND_TOPIC,
+    CONF_RGBWW_STATE_TOPIC,
+    CONF_RGBWW_VALUE_TEMPLATE,
     CONF_STATE_TOPIC,
     CONF_STATE_VALUE_TEMPLATE,
+    CONF_WHITE_COMMAND_TOPIC,
+    CONF_WHITE_SCALE,
+    CONF_XY_COMMAND_TEMPLATE,
+    CONF_XY_COMMAND_TOPIC,
+    CONF_XY_STATE_TOPIC,
+    CONF_XY_VALUE_TEMPLATE,
+    DEFAULT_BRIGHTNESS_SCALE,
+    DEFAULT_ON_COMMAND_TYPE,
+    DEFAULT_PAYLOAD_OFF,
+    DEFAULT_PAYLOAD_ON,
+    DEFAULT_WHITE_SCALE,
     PAYLOAD_NONE,
+    VALUES_ON_COMMAND_TYPE,
 )
-from ..debug_info import log_messages
-from ..mixins import MQTT_ENTITY_COMMON_SCHEMA, MqttEntity, write_state_on_attr_change
+from ..entity import MqttEntity
 from ..models import (
-    MessageCallbackType,
     MqttCommandTemplate,
     MqttValueTemplate,
     PayloadSentinel,
     PublishPayloadType,
     ReceiveMessage,
-    ReceivePayloadType,
     TemplateVarsType,
 )
+from ..schemas import MQTT_ENTITY_COMMON_SCHEMA
 from ..util import valid_publish_topic, valid_subscribe_topic
 from .schema import MQTT_LIGHT_SCHEMA_SCHEMA
 
 _LOGGER = logging.getLogger(__name__)
 
-CONF_BRIGHTNESS_COMMAND_TEMPLATE = "brightness_command_template"
-CONF_BRIGHTNESS_COMMAND_TOPIC = "brightness_command_topic"
-CONF_BRIGHTNESS_SCALE = "brightness_scale"
-CONF_BRIGHTNESS_STATE_TOPIC = "brightness_state_topic"
-CONF_BRIGHTNESS_VALUE_TEMPLATE = "brightness_value_template"
-CONF_COLOR_MODE_STATE_TOPIC = "color_mode_state_topic"
-CONF_COLOR_MODE_VALUE_TEMPLATE = "color_mode_value_template"
-CONF_COLOR_TEMP_COMMAND_TEMPLATE = "color_temp_command_template"
-CONF_COLOR_TEMP_COMMAND_TOPIC = "color_temp_command_topic"
-CONF_COLOR_TEMP_STATE_TOPIC = "color_temp_state_topic"
-CONF_COLOR_TEMP_VALUE_TEMPLATE = "color_temp_value_template"
-CONF_EFFECT_COMMAND_TEMPLATE = "effect_command_template"
-CONF_EFFECT_COMMAND_TOPIC = "effect_command_topic"
-CONF_EFFECT_LIST = "effect_list"
-CONF_EFFECT_STATE_TOPIC = "effect_state_topic"
-CONF_EFFECT_VALUE_TEMPLATE = "effect_value_template"
-CONF_HS_COMMAND_TEMPLATE = "hs_command_template"
-CONF_HS_COMMAND_TOPIC = "hs_command_topic"
-CONF_HS_STATE_TOPIC = "hs_state_topic"
-CONF_HS_VALUE_TEMPLATE = "hs_value_template"
-CONF_MAX_MIREDS = "max_mireds"
-CONF_MIN_MIREDS = "min_mireds"
-CONF_RGB_COMMAND_TEMPLATE = "rgb_command_template"
-CONF_RGB_COMMAND_TOPIC = "rgb_command_topic"
-CONF_RGB_STATE_TOPIC = "rgb_state_topic"
-CONF_RGB_VALUE_TEMPLATE = "rgb_value_template"
-CONF_RGBW_COMMAND_TEMPLATE = "rgbw_command_template"
-CONF_RGBW_COMMAND_TOPIC = "rgbw_command_topic"
-CONF_RGBW_STATE_TOPIC = "rgbw_state_topic"
-CONF_RGBW_VALUE_TEMPLATE = "rgbw_value_template"
-CONF_RGBWW_COMMAND_TEMPLATE = "rgbww_command_template"
-CONF_RGBWW_COMMAND_TOPIC = "rgbww_command_topic"
-CONF_RGBWW_STATE_TOPIC = "rgbww_state_topic"
-CONF_RGBWW_VALUE_TEMPLATE = "rgbww_value_template"
-CONF_XY_COMMAND_TEMPLATE = "xy_command_template"
-CONF_XY_COMMAND_TOPIC = "xy_command_topic"
-CONF_XY_STATE_TOPIC = "xy_state_topic"
-CONF_XY_VALUE_TEMPLATE = "xy_value_template"
-CONF_WHITE_COMMAND_TOPIC = "white_command_topic"
-CONF_WHITE_SCALE = "white_scale"
-CONF_ON_COMMAND_TYPE = "on_command_type"
+DEFAULT_NAME = "MQTT LightEntity"
 
 MQTT_LIGHT_ATTRIBUTES_BLOCKED = frozenset(
     {
         ATTR_COLOR_MODE,
         ATTR_BRIGHTNESS,
-        ATTR_COLOR_TEMP,
+        _DEPRECATED_ATTR_COLOR_TEMP.value,
+        ATTR_COLOR_TEMP_KELVIN,
         ATTR_EFFECT,
         ATTR_EFFECT_LIST,
         ATTR_HS_COLOR,
-        ATTR_MAX_MIREDS,
-        ATTR_MIN_MIREDS,
+        ATTR_MAX_COLOR_TEMP_KELVIN,
+        _DEPRECATED_ATTR_MAX_MIREDS.value,
+        ATTR_MIN_COLOR_TEMP_KELVIN,
+        _DEPRECATED_ATTR_MIN_MIREDS.value,
         ATTR_RGB_COLOR,
         ATTR_RGBW_COLOR,
         ATTR_RGBWW_COLOR,
@@ -129,15 +144,6 @@ MQTT_LIGHT_ATTRIBUTES_BLOCKED = frozenset(
     }
 )
 
-DEFAULT_BRIGHTNESS_SCALE = 255
-DEFAULT_NAME = "MQTT LightEntity"
-DEFAULT_PAYLOAD_OFF = "OFF"
-DEFAULT_PAYLOAD_ON = "ON"
-DEFAULT_WHITE_SCALE = 255
-DEFAULT_ON_COMMAND_TYPE = "last"
-
-VALUES_ON_COMMAND_TYPE = ["first", "last", "brightness"]
-
 COMMAND_TEMPLATE_KEYS = [
     CONF_BRIGHTNESS_COMMAND_TEMPLATE,
     CONF_COLOR_TEMP_COMMAND_TEMPLATE,
@@ -177,6 +183,7 @@ PLATFORM_SCHEMA_MODERN_BASIC = (
             vol.Optional(CONF_COLOR_TEMP_COMMAND_TOPIC): valid_publish_topic,
             vol.Optional(CONF_COLOR_TEMP_STATE_TOPIC): valid_subscribe_topic,
             vol.Optional(CONF_COLOR_TEMP_VALUE_TEMPLATE): cv.template,
+            vol.Optional(CONF_COLOR_TEMP_KELVIN, default=False): cv.boolean,
             vol.Optional(CONF_EFFECT_COMMAND_TEMPLATE): cv.template,
             vol.Optional(CONF_EFFECT_COMMAND_TOPIC): valid_publish_topic,
             vol.Optional(CONF_EFFECT_LIST): vol.All(cv.ensure_list, [cv.string]),
@@ -188,6 +195,8 @@ PLATFORM_SCHEMA_MODERN_BASIC = (
             vol.Optional(CONF_HS_VALUE_TEMPLATE): cv.template,
             vol.Optional(CONF_MAX_MIREDS): cv.positive_int,
             vol.Optional(CONF_MIN_MIREDS): cv.positive_int,
+            vol.Optional(CONF_MAX_KELVIN): cv.positive_int,
+            vol.Optional(CONF_MIN_KELVIN): cv.positive_int,
             vol.Optional(CONF_NAME): vol.Any(cv.string, None),
             vol.Optional(CONF_ON_COMMAND_TYPE, default=DEFAULT_ON_COMMAND_TYPE): vol.In(
                 VALUES_ON_COMMAND_TYPE
@@ -234,6 +243,7 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
     _attributes_extra_blocked = MQTT_LIGHT_ATTRIBUTES_BLOCKED
     _topic: dict[str, str | None]
     _payload: dict[str, str]
+    _color_temp_kelvin: bool
     _command_templates: dict[
         str, Callable[[PublishPayloadType, TemplateVarsType], PublishPayloadType]
     ]
@@ -243,7 +253,7 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
     _optimistic: bool
     _optimistic_brightness: bool
     _optimistic_color_mode: bool
-    _optimistic_color_temp: bool
+    _optimistic_color_temp_kelvin: bool
     _optimistic_effect: bool
     _optimistic_hs_color: bool
     _optimistic_rgb_color: bool
@@ -252,14 +262,24 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
     _optimistic_xy_color: bool
 
     @staticmethod
-    def config_schema() -> vol.Schema:
+    def config_schema() -> VolSchemaType:
         """Return the config schema."""
         return DISCOVERY_SCHEMA_BASIC
 
     def _setup_from_config(self, config: ConfigType) -> None:
         """(Re)Setup the entity."""
-        self._attr_min_mireds = config.get(CONF_MIN_MIREDS, super().min_mireds)
-        self._attr_max_mireds = config.get(CONF_MAX_MIREDS, super().max_mireds)
+        self._color_temp_kelvin = config[CONF_COLOR_TEMP_KELVIN]
+        self._attr_min_color_temp_kelvin = (
+            color_util.color_temperature_mired_to_kelvin(max_mireds)
+            if (max_mireds := config.get(CONF_MAX_MIREDS))
+            else config.get(CONF_MIN_KELVIN, DEFAULT_MIN_KELVIN)
+        )
+        self._attr_max_color_temp_kelvin = (
+            color_util.color_temperature_mired_to_kelvin(min_mireds)
+            if (min_mireds := config.get(CONF_MIN_MIREDS))
+            else config.get(CONF_MAX_KELVIN, DEFAULT_MAX_KELVIN)
+        )
+
         self._attr_effect_list = config.get(CONF_EFFECT_LIST)
 
         topic: dict[str, str | None] = {
@@ -324,7 +344,7 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
                 and topic[CONF_RGB_STATE_TOPIC] is None
             )
         )
-        self._optimistic_color_temp = (
+        self._optimistic_color_temp_kelvin = (
             optimistic or topic[CONF_COLOR_TEMP_STATE_TOPIC] is None
         )
         self._optimistic_effect = optimistic or topic[CONF_EFFECT_STATE_TOPIC] is None
@@ -376,271 +396,241 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
         attr: bool = getattr(self, f"_optimistic_{attribute}")
         return attr
 
-    def _prepare_subscribe_topics(self) -> None:  # noqa: C901
-        """(Re)Subscribe to topics."""
-        topics: dict[str, dict[str, Any]] = {}
+    @callback
+    def _state_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages."""
+        payload = self._value_templates[CONF_STATE_VALUE_TEMPLATE](
+            msg.payload, PayloadSentinel.NONE
+        )
+        if not payload:
+            _LOGGER.debug("Ignoring empty state message from '%s'", msg.topic)
+            return
 
-        def add_topic(topic: str, msg_callback: MessageCallbackType) -> None:
-            """Add a topic."""
-            if self._topic[topic] is not None:
-                topics[topic] = {
-                    "topic": self._topic[topic],
-                    "msg_callback": msg_callback,
-                    "qos": self._config[CONF_QOS],
-                    "encoding": self._config[CONF_ENCODING] or None,
-                }
+        if payload == self._payload["on"]:
+            self._attr_is_on = True
+        elif payload == self._payload["off"]:
+            self._attr_is_on = False
+        elif payload == PAYLOAD_NONE:
+            self._attr_is_on = None
 
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(self, {"_attr_is_on"})
-        def state_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages."""
-            payload = self._value_templates[CONF_STATE_VALUE_TEMPLATE](
-                msg.payload, PayloadSentinel.NONE
-            )
-            if not payload:
-                _LOGGER.debug("Ignoring empty state message from '%s'", msg.topic)
-                return
+    @callback
+    def _brightness_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for the brightness."""
+        payload = self._value_templates[CONF_BRIGHTNESS_VALUE_TEMPLATE](
+            msg.payload, PayloadSentinel.DEFAULT
+        )
+        if payload is PayloadSentinel.DEFAULT or not payload:
+            _LOGGER.debug("Ignoring empty brightness message from '%s'", msg.topic)
+            return
 
-            if payload == self._payload["on"]:
-                self._attr_is_on = True
-            elif payload == self._payload["off"]:
-                self._attr_is_on = False
-            elif payload == PAYLOAD_NONE:
-                self._attr_is_on = None
+        device_value = float(payload)
+        if device_value == 0:
+            _LOGGER.debug("Ignoring zero brightness from '%s'", msg.topic)
+            return
 
-        if self._topic[CONF_STATE_TOPIC] is not None:
-            topics[CONF_STATE_TOPIC] = {
-                "topic": self._topic[CONF_STATE_TOPIC],
-                "msg_callback": state_received,
-                "qos": self._config[CONF_QOS],
-                "encoding": self._config[CONF_ENCODING] or None,
-            }
+        percent_bright = device_value / self._config[CONF_BRIGHTNESS_SCALE]
+        self._attr_brightness = min(round(percent_bright * 255), 255)
 
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(self, {"_attr_brightness"})
-        def brightness_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for the brightness."""
-            payload = self._value_templates[CONF_BRIGHTNESS_VALUE_TEMPLATE](
-                msg.payload, PayloadSentinel.DEFAULT
-            )
-            if payload is PayloadSentinel.DEFAULT or not payload:
-                _LOGGER.debug("Ignoring empty brightness message from '%s'", msg.topic)
-                return
-
-            device_value = float(payload)
-            if device_value == 0:
-                _LOGGER.debug("Ignoring zero brightness from '%s'", msg.topic)
-                return
-
-            percent_bright = device_value / self._config[CONF_BRIGHTNESS_SCALE]
-            self._attr_brightness = min(round(percent_bright * 255), 255)
-
-        add_topic(CONF_BRIGHTNESS_STATE_TOPIC, brightness_received)
-
-        @callback
-        def _rgbx_received(
-            msg: ReceiveMessage,
-            template: str,
-            color_mode: ColorMode,
-            convert_color: Callable[..., tuple[int, ...]],
-        ) -> tuple[int, ...] | None:
-            """Handle new MQTT messages for RGBW and RGBWW."""
-            payload = self._value_templates[template](
-                msg.payload, PayloadSentinel.DEFAULT
-            )
-            if payload is PayloadSentinel.DEFAULT or not payload:
+    @callback
+    def _rgbx_received(
+        self,
+        msg: ReceiveMessage,
+        template: str,
+        color_mode: ColorMode,
+        convert_color: Callable[..., tuple[int, ...]],
+    ) -> tuple[int, ...] | None:
+        """Process MQTT messages for RGBW and RGBWW."""
+        payload = self._value_templates[template](msg.payload, PayloadSentinel.DEFAULT)
+        if payload is PayloadSentinel.DEFAULT or not payload:
+            _LOGGER.debug("Ignoring empty %s message from '%s'", color_mode, msg.topic)
+            return None
+        color = tuple(int(val) for val in str(payload).split(","))
+        if self._optimistic_color_mode:
+            self._attr_color_mode = color_mode
+        if self._topic[CONF_BRIGHTNESS_STATE_TOPIC] is None:
+            rgb = convert_color(*color)
+            brightness = max(rgb)
+            if brightness == 0:
                 _LOGGER.debug(
-                    "Ignoring empty %s message from '%s'", color_mode, msg.topic
+                    "Ignoring %s message with zero rgb brightness from '%s'",
+                    color_mode,
+                    msg.topic,
                 )
                 return None
-            color = tuple(int(val) for val in str(payload).split(","))
-            if self._optimistic_color_mode:
-                self._attr_color_mode = color_mode
-            if self._topic[CONF_BRIGHTNESS_STATE_TOPIC] is None:
-                rgb = convert_color(*color)
-                brightness = max(rgb)
-                if brightness == 0:
-                    _LOGGER.debug(
-                        "Ignoring %s message with zero rgb brightness from '%s'",
-                        color_mode,
-                        msg.topic,
-                    )
-                    return None
-                self._attr_brightness = brightness
-                # Normalize the color to 100% brightness
-                color = tuple(
-                    min(round(channel / brightness * 255), 255) for channel in color
-                )
-            return color
+            self._attr_brightness = brightness
+            # Normalize the color to 100% brightness
+            color = tuple(
+                min(round(channel / brightness * 255), 255) for channel in color
+            )
+        return color
 
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(
-            self, {"_attr_brightness", "_attr_color_mode", "_attr_rgb_color"}
+    @callback
+    def _rgb_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for RGB."""
+        rgb = self._rgbx_received(
+            msg, CONF_RGB_VALUE_TEMPLATE, ColorMode.RGB, lambda *x: x
         )
-        def rgb_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for RGB."""
-            rgb = _rgbx_received(
-                msg, CONF_RGB_VALUE_TEMPLATE, ColorMode.RGB, lambda *x: x
-            )
-            if rgb is None:
-                return
-            self._attr_rgb_color = cast(tuple[int, int, int], rgb)
+        if rgb is None:
+            return
+        self._attr_rgb_color = cast(tuple[int, int, int], rgb)
 
-        add_topic(CONF_RGB_STATE_TOPIC, rgb_received)
-
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(
-            self, {"_attr_brightness", "_attr_color_mode", "_attr_rgbw_color"}
+    @callback
+    def _rgbw_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for RGBW."""
+        rgbw = self._rgbx_received(
+            msg,
+            CONF_RGBW_VALUE_TEMPLATE,
+            ColorMode.RGBW,
+            color_util.color_rgbw_to_rgb,
         )
-        def rgbw_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for RGBW."""
-            rgbw = _rgbx_received(
-                msg,
-                CONF_RGBW_VALUE_TEMPLATE,
-                ColorMode.RGBW,
-                color_util.color_rgbw_to_rgb,
-            )
-            if rgbw is None:
-                return
-            self._attr_rgbw_color = cast(tuple[int, int, int, int], rgbw)
+        if rgbw is None:
+            return
+        self._attr_rgbw_color = cast(tuple[int, int, int, int], rgbw)
 
-        add_topic(CONF_RGBW_STATE_TOPIC, rgbw_received)
+    @callback
+    def _rgbww_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for RGBWW."""
 
         @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(
-            self, {"_attr_brightness", "_attr_color_mode", "_attr_rgbww_color"}
+        def _converter(
+            r: int, g: int, b: int, cw: int, ww: int
+        ) -> tuple[int, int, int]:
+            return color_util.color_rgbww_to_rgb(
+                r, g, b, cw, ww, self.min_color_temp_kelvin, self.max_color_temp_kelvin
+            )
+
+        rgbww = self._rgbx_received(
+            msg,
+            CONF_RGBWW_VALUE_TEMPLATE,
+            ColorMode.RGBWW,
+            _converter,
         )
-        def rgbww_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for RGBWW."""
+        if rgbww is None:
+            return
+        self._attr_rgbww_color = cast(tuple[int, int, int, int, int], rgbww)
 
-            @callback
-            def _converter(
-                r: int, g: int, b: int, cw: int, ww: int
-            ) -> tuple[int, int, int]:
-                min_kelvin = color_util.color_temperature_mired_to_kelvin(
-                    self.max_mireds
-                )
-                max_kelvin = color_util.color_temperature_mired_to_kelvin(
-                    self.min_mireds
-                )
-                return color_util.color_rgbww_to_rgb(
-                    r, g, b, cw, ww, min_kelvin, max_kelvin
-                )
+    @callback
+    def _color_mode_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for color mode."""
+        payload = self._value_templates[CONF_COLOR_MODE_VALUE_TEMPLATE](
+            msg.payload, PayloadSentinel.DEFAULT
+        )
+        if payload is PayloadSentinel.DEFAULT or not payload:
+            _LOGGER.debug("Ignoring empty color mode message from '%s'", msg.topic)
+            return
 
-            rgbww = _rgbx_received(
-                msg,
-                CONF_RGBWW_VALUE_TEMPLATE,
-                ColorMode.RGBWW,
-                _converter,
-            )
-            if rgbww is None:
-                return
-            self._attr_rgbww_color = cast(tuple[int, int, int, int, int], rgbww)
+        self._attr_color_mode = ColorMode(str(payload))
 
-        add_topic(CONF_RGBWW_STATE_TOPIC, rgbww_received)
+    @callback
+    def _color_temp_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for color temperature."""
+        payload = self._value_templates[CONF_COLOR_TEMP_VALUE_TEMPLATE](
+            msg.payload, PayloadSentinel.DEFAULT
+        )
+        if payload is PayloadSentinel.DEFAULT or not payload:
+            _LOGGER.debug("Ignoring empty color temp message from '%s'", msg.topic)
+            return
 
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(self, {"_attr_color_mode"})
-        def color_mode_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for color mode."""
-            payload = self._value_templates[CONF_COLOR_MODE_VALUE_TEMPLATE](
-                msg.payload, PayloadSentinel.DEFAULT
-            )
-            if payload is PayloadSentinel.DEFAULT or not payload:
-                _LOGGER.debug("Ignoring empty color mode message from '%s'", msg.topic)
-                return
+        if self._optimistic_color_mode:
+            self._attr_color_mode = ColorMode.COLOR_TEMP
+        if self._color_temp_kelvin:
+            self._attr_color_temp_kelvin = int(payload)
+            return
+        self._attr_color_temp_kelvin = color_util.color_temperature_mired_to_kelvin(
+            int(payload)
+        )
 
-            self._attr_color_mode = ColorMode(str(payload))
+    @callback
+    def _effect_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for effect."""
+        payload = self._value_templates[CONF_EFFECT_VALUE_TEMPLATE](
+            msg.payload, PayloadSentinel.DEFAULT
+        )
+        if payload is PayloadSentinel.DEFAULT or not payload:
+            _LOGGER.debug("Ignoring empty effect message from '%s'", msg.topic)
+            return
 
-        add_topic(CONF_COLOR_MODE_STATE_TOPIC, color_mode_received)
-
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(self, {"_attr_color_mode", "_attr_color_temp"})
-        def color_temp_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for color temperature."""
-            payload = self._value_templates[CONF_COLOR_TEMP_VALUE_TEMPLATE](
-                msg.payload, PayloadSentinel.DEFAULT
-            )
-            if payload is PayloadSentinel.DEFAULT or not payload:
-                _LOGGER.debug("Ignoring empty color temp message from '%s'", msg.topic)
-                return
+        self._attr_effect = str(payload)
 
+    @callback
+    def _hs_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for hs color."""
+        payload = self._value_templates[CONF_HS_VALUE_TEMPLATE](
+            msg.payload, PayloadSentinel.DEFAULT
+        )
+        if payload is PayloadSentinel.DEFAULT or not payload:
+            _LOGGER.debug("Ignoring empty hs message from '%s'", msg.topic)
+            return
+        try:
+            hs_color = tuple(float(val) for val in str(payload).split(",", 2))
             if self._optimistic_color_mode:
-                self._attr_color_mode = ColorMode.COLOR_TEMP
-            self._attr_color_temp = int(payload)
+                self._attr_color_mode = ColorMode.HS
+            self._attr_hs_color = cast(tuple[float, float], hs_color)
+        except ValueError:
+            _LOGGER.warning("Failed to parse hs state update: '%s'", payload)
 
-        add_topic(CONF_COLOR_TEMP_STATE_TOPIC, color_temp_received)
+    @callback
+    def _xy_received(self, msg: ReceiveMessage) -> None:
+        """Handle new MQTT messages for xy color."""
+        payload = self._value_templates[CONF_XY_VALUE_TEMPLATE](
+            msg.payload, PayloadSentinel.DEFAULT
+        )
+        if payload is PayloadSentinel.DEFAULT or not payload:
+            _LOGGER.debug("Ignoring empty xy-color message from '%s'", msg.topic)
+            return
 
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(self, {"_attr_effect"})
-        def effect_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for effect."""
-            payload = self._value_templates[CONF_EFFECT_VALUE_TEMPLATE](
-                msg.payload, PayloadSentinel.DEFAULT
-            )
-            if payload is PayloadSentinel.DEFAULT or not payload:
-                _LOGGER.debug("Ignoring empty effect message from '%s'", msg.topic)
-                return
+        xy_color = tuple(float(val) for val in str(payload).split(",", 2))
+        if self._optimistic_color_mode:
+            self._attr_color_mode = ColorMode.XY
+        self._attr_xy_color = cast(tuple[float, float], xy_color)
 
-            self._attr_effect = str(payload)
-
-        add_topic(CONF_EFFECT_STATE_TOPIC, effect_received)
-
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(self, {"_attr_color_mode", "_attr_hs_color"})
-        def hs_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for hs color."""
-            payload = self._value_templates[CONF_HS_VALUE_TEMPLATE](
-                msg.payload, PayloadSentinel.DEFAULT
-            )
-            if payload is PayloadSentinel.DEFAULT or not payload:
-                _LOGGER.debug("Ignoring empty hs message from '%s'", msg.topic)
-                return
-            try:
-                hs_color = tuple(float(val) for val in str(payload).split(",", 2))
-                if self._optimistic_color_mode:
-                    self._attr_color_mode = ColorMode.HS
-                self._attr_hs_color = cast(tuple[float, float], hs_color)
-            except ValueError:
-                _LOGGER.warning("Failed to parse hs state update: '%s'", payload)
-
-        add_topic(CONF_HS_STATE_TOPIC, hs_received)
-
-        @callback
-        @log_messages(self.hass, self.entity_id)
-        @write_state_on_attr_change(self, {"_attr_color_mode", "_attr_xy_color"})
-        def xy_received(msg: ReceiveMessage) -> None:
-            """Handle new MQTT messages for xy color."""
-            payload = self._value_templates[CONF_XY_VALUE_TEMPLATE](
-                msg.payload, PayloadSentinel.DEFAULT
-            )
-            if payload is PayloadSentinel.DEFAULT or not payload:
-                _LOGGER.debug("Ignoring empty xy-color message from '%s'", msg.topic)
-                return
-
-            xy_color = tuple(float(val) for val in str(payload).split(",", 2))
-            if self._optimistic_color_mode:
-                self._attr_color_mode = ColorMode.XY
-            self._attr_xy_color = cast(tuple[float, float], xy_color)
-
-        add_topic(CONF_XY_STATE_TOPIC, xy_received)
-
-        self._sub_state = subscription.async_prepare_subscribe_topics(
-            self.hass, self._sub_state, topics
+    @callback
+    def _prepare_subscribe_topics(self) -> None:
+        """(Re)Subscribe to topics."""
+        self.add_subscription(CONF_STATE_TOPIC, self._state_received, {"_attr_is_on"})
+        self.add_subscription(
+            CONF_BRIGHTNESS_STATE_TOPIC, self._brightness_received, {"_attr_brightness"}
+        )
+        self.add_subscription(
+            CONF_RGB_STATE_TOPIC,
+            self._rgb_received,
+            {"_attr_brightness", "_attr_color_mode", "_attr_rgb_color"},
+        )
+        self.add_subscription(
+            CONF_RGBW_STATE_TOPIC,
+            self._rgbw_received,
+            {"_attr_brightness", "_attr_color_mode", "_attr_rgbw_color"},
+        )
+        self.add_subscription(
+            CONF_RGBWW_STATE_TOPIC,
+            self._rgbww_received,
+            {"_attr_brightness", "_attr_color_mode", "_attr_rgbww_color"},
+        )
+        self.add_subscription(
+            CONF_COLOR_MODE_STATE_TOPIC, self._color_mode_received, {"_attr_color_mode"}
+        )
+        self.add_subscription(
+            CONF_COLOR_TEMP_STATE_TOPIC,
+            self._color_temp_received,
+            {"_attr_color_mode", "_attr_color_temp_kelvin"},
+        )
+        self.add_subscription(
+            CONF_EFFECT_STATE_TOPIC, self._effect_received, {"_attr_effect"}
+        )
+        self.add_subscription(
+            CONF_HS_STATE_TOPIC,
+            self._hs_received,
+            {"_attr_color_mode", "_attr_hs_color"},
+        )
+        self.add_subscription(
+            CONF_XY_STATE_TOPIC,
+            self._xy_received,
+            {"_attr_color_mode", "_attr_xy_color"},
         )
 
     async def _subscribe_topics(self) -> None:
         """(Re)Subscribe to topics."""
-        await subscription.async_subscribe_topics(self.hass, self._sub_state)
+        subscription.async_subscribe_topics_internal(self.hass, self._sub_state)
         last_state = await self.async_get_last_state()
 
         def restore_state(
@@ -661,7 +651,7 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
         restore_state(ATTR_RGBW_COLOR)
         restore_state(ATTR_RGBWW_COLOR)
         restore_state(ATTR_COLOR_MODE)
-        restore_state(ATTR_COLOR_TEMP)
+        restore_state(ATTR_COLOR_TEMP_KELVIN)
         restore_state(ATTR_EFFECT)
         restore_state(ATTR_HS_COLOR)
         restore_state(ATTR_XY_COLOR)
@@ -677,13 +667,7 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
 
         async def publish(topic: str, payload: PublishPayloadType) -> None:
             """Publish an MQTT message."""
-            await self.async_publish(
-                str(self._topic[topic]),
-                payload,
-                self._config[CONF_QOS],
-                self._config[CONF_RETAIN],
-                self._config[CONF_ENCODING],
-            )
+            await self.async_publish_with_config(str(self._topic[topic]), payload)
 
         def scale_rgbx(
             color: tuple[int, ...],
@@ -711,7 +695,7 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
                 keys.append("white")
             elif color_mode == ColorMode.RGBWW:
                 keys.extend(["cold_white", "warm_white"])
-            variables = dict(zip(keys, color))
+            variables = dict(zip(keys, color, strict=False))
             return self._command_templates[template](rgb_color_str, variables)
 
         def set_optimistic(
@@ -839,14 +823,23 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
             await publish(CONF_RGBWW_COMMAND_TOPIC, rgbww_s)
             should_update |= set_optimistic(ATTR_BRIGHTNESS, kwargs[ATTR_BRIGHTNESS])
         if (
-            ATTR_COLOR_TEMP in kwargs
+            ATTR_COLOR_TEMP_KELVIN in kwargs
             and self._topic[CONF_COLOR_TEMP_COMMAND_TOPIC] is not None
         ):
             ct_command_tpl = self._command_templates[CONF_COLOR_TEMP_COMMAND_TEMPLATE]
-            color_temp = ct_command_tpl(int(kwargs[ATTR_COLOR_TEMP]), None)
+            color_temp = ct_command_tpl(
+                kwargs[ATTR_COLOR_TEMP_KELVIN]
+                if self._color_temp_kelvin
+                else color_util.color_temperature_kelvin_to_mired(
+                    kwargs[ATTR_COLOR_TEMP_KELVIN]
+                ),
+                None,
+            )
             await publish(CONF_COLOR_TEMP_COMMAND_TOPIC, color_temp)
             should_update |= set_optimistic(
-                ATTR_COLOR_TEMP, kwargs[ATTR_COLOR_TEMP], ColorMode.COLOR_TEMP
+                ATTR_COLOR_TEMP_KELVIN,
+                kwargs[ATTR_COLOR_TEMP_KELVIN],
+                ColorMode.COLOR_TEMP,
             )
 
         if (
@@ -888,12 +881,8 @@ class MqttLight(MqttEntity, LightEntity, RestoreEntity):
 
         This method is a coroutine.
         """
-        await self.async_publish(
-            str(self._topic[CONF_COMMAND_TOPIC]),
-            self._payload["off"],
-            self._config[CONF_QOS],
-            self._config[CONF_RETAIN],
-            self._config[CONF_ENCODING],
+        await self.async_publish_with_config(
+            str(self._topic[CONF_COMMAND_TOPIC]), self._payload["off"]
         )
 
         if self._optimistic:
