@@ -1,23 +1,30 @@
 """Camera platform that receives images through HTTP POST."""
+
 from __future__ import annotations
 
 import asyncio
 from collections import deque
 from datetime import timedelta
 import logging
+from typing import cast
 
-import aiohttp
+from aiohttp import web
 import voluptuous as vol
 
 from homeassistant.components import webhook
-from homeassistant.components.camera import DOMAIN, PLATFORM_SCHEMA, STATE_IDLE, Camera
+from homeassistant.components.camera import (
+    DOMAIN as CAMERA_DOMAIN,
+    PLATFORM_SCHEMA as CAMERA_PLATFORM_SCHEMA,
+    Camera,
+    CameraState,
+)
 from homeassistant.const import CONF_NAME, CONF_TIMEOUT, CONF_WEBHOOK_ID
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.event import async_track_point_in_utc_time
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
-import homeassistant.util.dt as dt_util
+from homeassistant.util import dt as dt_util
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -31,7 +38,7 @@ ATTR_LAST_TRIP = "last_trip"
 
 PUSH_CAMERA_DATA = "push_camera"
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+PLATFORM_SCHEMA = CAMERA_PLATFORM_SCHEMA.extend(
     {
         vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
         vol.Optional(CONF_BUFFER_SIZE, default=1): cv.positive_int,
@@ -54,7 +61,7 @@ async def async_setup_platform(
     if PUSH_CAMERA_DATA not in hass.data:
         hass.data[PUSH_CAMERA_DATA] = {}
 
-    webhook_id = config.get(CONF_WEBHOOK_ID)
+    webhook_id = config[CONF_WEBHOOK_ID]
 
     cameras = [
         PushCamera(
@@ -70,12 +77,14 @@ async def async_setup_platform(
     async_add_entities(cameras)
 
 
-async def handle_webhook(hass, webhook_id, request):
+async def handle_webhook(
+    hass: HomeAssistant, webhook_id: str, request: web.Request
+) -> None:
     """Handle incoming webhook POST with image files."""
     try:
         async with asyncio.timeout(5):
             data = dict(await request.post())
-    except (asyncio.TimeoutError, aiohttp.web.HTTPException) as error:
+    except (TimeoutError, web.HTTPException) as error:
         _LOGGER.error("Could not get information from POST <%s>", error)
         return
 
@@ -85,24 +94,34 @@ async def handle_webhook(hass, webhook_id, request):
         _LOGGER.warning("Webhook call without POST parameter <%s>", camera.image_field)
         return
 
-    await camera.update_image(
-        data[camera.image_field].file.read(), data[camera.image_field].filename
-    )
+    image_data = cast(web.FileField, data[camera.image_field])
+    await camera.update_image(image_data.file.read(), image_data.filename)
 
 
 class PushCamera(Camera):
     """The representation of a Push camera."""
 
-    def __init__(self, hass, name, buffer_size, timeout, image_field, webhook_id):
+    _attr_motion_detection_enabled = False
+    name: str
+
+    def __init__(
+        self,
+        hass: HomeAssistant,
+        name: str,
+        buffer_size: int,
+        timeout: timedelta,
+        image_field: str,
+        webhook_id: str,
+    ) -> None:
         """Initialize push camera component."""
         super().__init__()
-        self._name = name
+        self._attr_name = name
         self._last_trip = None
         self._filename = None
         self._expired_listener = None
         self._timeout = timeout
-        self.queue = deque([], buffer_size)
-        self._current_image = None
+        self.queue: deque[bytes] = deque([], buffer_size)
+        self._current_image: bytes | None = None
         self._image_field = image_field
         self.webhook_id = webhook_id
         self.webhook_url = webhook.async_generate_url(hass, webhook_id)
@@ -113,7 +132,7 @@ class PushCamera(Camera):
 
         try:
             webhook.async_register(
-                self.hass, DOMAIN, self.name, self.webhook_id, handle_webhook
+                self.hass, CAMERA_DOMAIN, self.name, self.webhook_id, handle_webhook
             )
         except ValueError:
             _LOGGER.error(
@@ -127,7 +146,7 @@ class PushCamera(Camera):
 
     async def update_image(self, image, filename):
         """Update the camera image."""
-        if self.state == STATE_IDLE:
+        if self.state == CameraState.IDLE:
             self._attr_is_recording = True
             self._last_trip = dt_util.utcnow()
             self.queue.clear()
@@ -157,22 +176,12 @@ class PushCamera(Camera):
     ) -> bytes | None:
         """Return a still image response."""
         if self.queue:
-            if self.state == STATE_IDLE:
+            if self.state == CameraState.IDLE:
                 self.queue.rotate(1)
             self._current_image = self.queue[0]
 
         return self._current_image
 
-    @property
-    def name(self):
-        """Return the name of this camera."""
-        return self._name
-
-    @property
-    def motion_detection_enabled(self):
-        """Camera Motion Detection Status."""
-        return False
-
     @property
     def extra_state_attributes(self):
         """Return the state attributes."""
