@@ -1,16 +1,26 @@
 """Config flow to configure roomba component."""
 
-import asyncio
+from __future__ import annotations
 
-from roombapy import RoombaFactory
+import asyncio
+from functools import partial
+from typing import Any
+
+from roombapy import RoombaFactory, RoombaInfo
 from roombapy.discovery import RoombaDiscovery
 from roombapy.getpassword import RoombaPassword
 import voluptuous as vol
 
-from homeassistant import config_entries, core
-from homeassistant.components.dhcp import HOSTNAME, IP_ADDRESS
+from homeassistant.config_entries import (
+    ConfigEntry,
+    ConfigFlow,
+    ConfigFlowResult,
+    OptionsFlow,
+)
 from homeassistant.const import CONF_DELAY, CONF_HOST, CONF_NAME, CONF_PASSWORD
-from homeassistant.core import callback
+from homeassistant.core import HomeAssistant, callback
+from homeassistant.helpers.service_info.dhcp import DhcpServiceInfo
+from homeassistant.helpers.service_info.zeroconf import ZeroconfServiceInfo
 
 from . import CannotConnect, async_connect_or_timeout, async_disconnect_or_timeout
 from .const import (
@@ -32,20 +42,25 @@ DEFAULT_OPTIONS = {CONF_CONTINUOUS: DEFAULT_CONTINUOUS, CONF_DELAY: DEFAULT_DELA
 MAX_NUM_DEVICES_TO_DISCOVER = 25
 
 AUTH_HELP_URL_KEY = "auth_help_url"
-AUTH_HELP_URL_VALUE = "https://www.home-assistant.io/integrations/roomba/#manually-retrieving-your-credentials"
+AUTH_HELP_URL_VALUE = (
+    "https://www.home-assistant.io/integrations/roomba/#retrieving-your-credentials"
+)
 
 
-async def validate_input(hass: core.HomeAssistant, data):
+async def validate_input(hass: HomeAssistant, data: dict[str, Any]) -> dict[str, Any]:
     """Validate the user input allows us to connect.
 
     Data has the keys from DATA_SCHEMA with values provided by the user.
     """
-    roomba = RoombaFactory.create_roomba(
-        address=data[CONF_HOST],
-        blid=data[CONF_BLID],
-        password=data[CONF_PASSWORD],
-        continuous=False,
-        delay=data[CONF_DELAY],
+    roomba = await hass.async_add_executor_job(
+        partial(
+            RoombaFactory.create_roomba,
+            address=data[CONF_HOST],
+            blid=data[CONF_BLID],
+            password=data[CONF_PASSWORD],
+            continuous=True,
+            delay=data[CONF_DELAY],
+        )
     )
 
     info = await async_connect_or_timeout(hass, roomba)
@@ -59,37 +74,56 @@ async def validate_input(hass: core.HomeAssistant, data):
     }
 
 
-class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
+class RoombaConfigFlow(ConfigFlow, domain=DOMAIN):
     """Roomba configuration flow."""
 
     VERSION = 1
-    CONNECTION_CLASS = config_entries.CONN_CLASS_LOCAL_PUSH
 
-    def __init__(self):
+    name: str | None = None
+    blid: str
+    host: str | None = None
+
+    def __init__(self) -> None:
         """Initialize the roomba flow."""
-        self.discovered_robots = {}
-        self.name = None
-        self.blid = None
-        self.host = None
+        self.discovered_robots: dict[str, RoombaInfo] = {}
 
     @staticmethod
     @callback
-    def async_get_options_flow(config_entry):
+    def async_get_options_flow(
+        config_entry: ConfigEntry,
+    ) -> RoombaOptionsFlowHandler:
         """Get the options flow for this handler."""
-        return OptionsFlowHandler(config_entry)
+        return RoombaOptionsFlowHandler()
 
-    async def async_step_dhcp(self, discovery_info):
+    async def async_step_zeroconf(
+        self, discovery_info: ZeroconfServiceInfo
+    ) -> ConfigFlowResult:
+        """Handle zeroconf discovery."""
+        return await self._async_step_discovery(
+            discovery_info.host, discovery_info.hostname.lower().removesuffix(".local.")
+        )
+
+    async def async_step_dhcp(
+        self, discovery_info: DhcpServiceInfo
+    ) -> ConfigFlowResult:
         """Handle dhcp discovery."""
-        if self._async_host_already_configured(discovery_info[IP_ADDRESS]):
-            return self.async_abort(reason="already_configured")
+        return await self._async_step_discovery(
+            discovery_info.ip, discovery_info.hostname
+        )
 
-        if not discovery_info[HOSTNAME].startswith(("irobot-", "roomba-")):
+    async def _async_step_discovery(
+        self, ip_address: str, hostname: str
+    ) -> ConfigFlowResult:
+        """Handle any discovery."""
+        self._async_abort_entries_match({CONF_HOST: ip_address})
+
+        if not hostname.startswith(("irobot-", "roomba-")):
             return self.async_abort(reason="not_irobot_device")
 
-        self.host = discovery_info[IP_ADDRESS]
-        self.blid = _async_blid_from_hostname(discovery_info[HOSTNAME])
+        self.host = ip_address
+        self.blid = _async_blid_from_hostname(hostname)
         await self.async_set_unique_id(self.blid)
-        self._abort_if_unique_id_configured(updates={CONF_HOST: self.host})
+        self._abort_if_unique_id_configured(updates={CONF_HOST: ip_address})
 
         # Because the hostname is so long some sources may
         # truncate the hostname since it will be longer than
@@ -97,7 +131,9 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         # going for a longer hostname we abort so the user
         # does not see two flows if discovery fails.
         for progress in self._async_in_progress():
-            flow_unique_id = progress["context"]["unique_id"]
+            flow_unique_id = progress["context"].get("unique_id")
+            if not flow_unique_id:
+                continue
             if flow_unique_id.startswith(self.blid):
                 return self.async_abort(reason="short_blid")
             if self.blid.startswith(flow_unique_id):
@@ -106,8 +142,9 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         self.context["title_placeholders"] = {"host": self.host, "name": self.blid}
         return await self.async_step_user()
 
-    async def _async_start_link(self):
+    async def _async_start_link(self) -> ConfigFlowResult:
         """Start linking."""
+        assert self.host
         device = self.discovered_robots[self.host]
         self.blid = device.blid
         self.name = device.robot_name
@@ -115,7 +152,9 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         self._abort_if_unique_id_configured()
         return await self.async_step_link()
 
-    async def async_step_user(self, user_input=None):
+    async def async_step_user(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Handle a flow start."""
         # Check if user chooses manual entry
         if user_input is not None and not user_input.get(CONF_HOST):
@@ -152,51 +191,50 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         if not self.discovered_robots:
             return await self.async_step_manual()
 
+        hosts: dict[str | None, str] = {
+            **{
+                device.ip: f"{device.robot_name} ({device.ip})"
+                for device in devices
+                if device.blid not in already_configured
+            },
+            None: "Manually add a Roomba or Braava",
+        }
+
         return self.async_show_form(
             step_id="user",
-            data_schema=vol.Schema(
-                {
-                    vol.Optional("host"): vol.In(
-                        {
-                            **{
-                                device.ip: f"{device.robot_name} ({device.ip})"
-                                for device in devices
-                                if device.blid not in already_configured
-                            },
-                            None: "Manually add a Roomba or Braava",
-                        }
-                    )
-                }
-            ),
+            data_schema=vol.Schema({vol.Optional("host"): vol.In(hosts)}),
         )
 
-    async def async_step_manual(self, user_input=None):
+    async def async_step_manual(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Handle manual device setup."""
         if user_input is None:
             return self.async_show_form(
                 step_id="manual",
                 description_placeholders={AUTH_HELP_URL_KEY: AUTH_HELP_URL_VALUE},
                 data_schema=vol.Schema(
-                    {
-                        vol.Required(CONF_HOST, default=self.host): str,
-                        vol.Required(CONF_BLID, default=self.blid): str,
-                    }
+                    {vol.Required(CONF_HOST, default=self.host): str}
                 ),
             )
 
-        if any(
-            user_input["host"] == entry.data.get("host")
-            for entry in self._async_current_entries()
-        ):
-            return self.async_abort(reason="already_configured")
+        self._async_abort_entries_match({CONF_HOST: user_input["host"]})
 
         self.host = user_input[CONF_HOST]
-        self.blid = user_input[CONF_BLID].upper()
+
+        devices = await _async_discover_roombas(self.hass, self.host)
+        if not devices:
+            return self.async_abort(reason="cannot_connect")
+        self.blid = devices[0].blid
+        self.name = devices[0].robot_name
+
         await self.async_set_unique_id(self.blid, raise_on_progress=False)
         self._abort_if_unique_id_configured()
         return await self.async_step_link()
 
-    async def async_step_link(self, user_input=None):
+    async def async_step_link(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Attempt to link with the Roomba.
 
         Given a configured host, will ask the user to press the home and target buttons
@@ -207,12 +245,12 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
                 step_id="link",
                 description_placeholders={CONF_NAME: self.name or self.blid},
             )
-
+        assert self.host
         roomba_pw = RoombaPassword(self.host)
 
         try:
             password = await self.hass.async_add_executor_job(roomba_pw.get_password)
-        except (OSError, ConnectionRefusedError):
+        except OSError:
             return await self.async_step_link_manual()
 
         if not password:
@@ -232,10 +270,12 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
                 return self.async_abort(reason="cannot_connect")
 
             self.name = info[CONF_NAME]
-
+        assert self.name
         return self.async_create_entry(title=self.name, data=config)
 
-    async def async_step_link_manual(self, user_input=None):
+    async def async_step_link_manual(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Handle manual linking."""
         errors = {}
 
@@ -250,8 +290,7 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
                 info = await validate_input(self.hass, config)
             except CannotConnect:
                 errors = {"base": "cannot_connect"}
-
-            if not errors:
+            else:
                 return self.async_create_entry(title=info[CONF_NAME], data=config)
 
         return self.async_show_form(
@@ -261,42 +300,29 @@ class RoombaConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             errors=errors,
         )
 
-    @callback
-    def _async_host_already_configured(self, host):
-        """See if we already have an entry matching the host."""
-        for entry in self._async_current_entries():
-            if entry.data.get(CONF_HOST) == host:
-                return True
-        return False
 
-
-class OptionsFlowHandler(config_entries.OptionsFlow):
+class RoombaOptionsFlowHandler(OptionsFlow):
     """Handle options."""
 
-    def __init__(self, config_entry):
-        """Initialize options flow."""
-        self.config_entry = config_entry
-
-    async def async_step_init(self, user_input=None):
+    async def async_step_init(
+        self, user_input: dict[str, Any] | None = None
+    ) -> ConfigFlowResult:
         """Manage the options."""
         if user_input is not None:
             return self.async_create_entry(title="", data=user_input)
 
+        options = self.config_entry.options
         return self.async_show_form(
             step_id="init",
             data_schema=vol.Schema(
                 {
                     vol.Optional(
                         CONF_CONTINUOUS,
-                        default=self.config_entry.options.get(
-                            CONF_CONTINUOUS, DEFAULT_CONTINUOUS
-                        ),
+                        default=options.get(CONF_CONTINUOUS, DEFAULT_CONTINUOUS),
                     ): bool,
                     vol.Optional(
                         CONF_DELAY,
-                        default=self.config_entry.options.get(
-                            CONF_DELAY, DEFAULT_DELAY
-                        ),
+                        default=options.get(CONF_DELAY, DEFAULT_DELAY),
                     ): int,
                 }
             ),
@@ -304,7 +330,7 @@ class OptionsFlowHandler(config_entries.OptionsFlow):
 
 
 @callback
-def _async_get_roomba_discovery():
+def _async_get_roomba_discovery() -> RoombaDiscovery:
     """Create a discovery object."""
     discovery = RoombaDiscovery()
     discovery.amount_of_broadcasted_messages = MAX_NUM_DEVICES_TO_DISCOVER
@@ -312,24 +338,28 @@ def _async_get_roomba_discovery():
 
 
 @callback
-def _async_blid_from_hostname(hostname):
+def _async_blid_from_hostname(hostname: str) -> str:
     """Extract the blid from the hostname."""
     return hostname.split("-")[1].split(".")[0].upper()
 
 
-async def _async_discover_roombas(hass, host):
-    discovered_hosts = set()
-    devices = []
+async def _async_discover_roombas(
+    hass: HomeAssistant, host: str | None = None
+) -> list[RoombaInfo]:
+    discovered_hosts: set[str] = set()
+    devices: list[RoombaInfo] = []
     discover_lock = hass.data.setdefault(ROOMBA_DISCOVERY_LOCK, asyncio.Lock())
     discover_attempts = HOST_ATTEMPTS if host else ALL_ATTEMPTS
 
     for attempt in range(discover_attempts + 1):
         async with discover_lock:
             discovery = _async_get_roomba_discovery()
+            discovered: set[RoombaInfo] = set()
             try:
                 if host:
                     device = await hass.async_add_executor_job(discovery.get, host)
-                    discovered = [device] if device else []
+                    if device:
+                        discovered.add(device)
                 else:
                     discovered = await hass.async_add_executor_job(discovery.get_all)
             except OSError:
