@@ -18,13 +18,13 @@ from homeassistant.components.cover import (
     CoverEntity,
     CoverEntityFeature,
 )
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     CONF_COVERS,
     CONF_DEVICE_CLASS,
     CONF_ENTITY_ID,
     CONF_FRIENDLY_NAME,
     CONF_NAME,
-    CONF_OPTIMISTIC,
     CONF_STATE,
     CONF_UNIQUE_ID,
     CONF_VALUE_TEMPLATE,
@@ -32,19 +32,26 @@ from homeassistant.const import (
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import TemplateError
 from homeassistant.helpers import config_validation as cv, template
-from homeassistant.helpers.entity import async_generate_entity_id
-from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.entity_platform import (
+    AddConfigEntryEntitiesCallback,
+    AddEntitiesCallback,
+)
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 from . import TriggerUpdateCoordinator
-from .const import CONF_OBJECT_ID, DOMAIN
+from .const import DOMAIN
 from .entity import AbstractTemplateEntity
+from .helpers import (
+    async_setup_template_entry,
+    async_setup_template_platform,
+    async_setup_template_preview,
+)
 from .template_entity import (
-    LEGACY_FIELDS as TEMPLATE_ENTITY_LEGACY_FIELDS,
+    TEMPLATE_ENTITY_COMMON_CONFIG_ENTRY_SCHEMA,
     TEMPLATE_ENTITY_COMMON_SCHEMA_LEGACY,
+    TEMPLATE_ENTITY_OPTIMISTIC_SCHEMA,
     TemplateEntity,
     make_template_entity_common_modern_schema,
-    rewrite_common_legacy_to_modern_conf,
 )
 from .trigger_entity import TriggerEntity
 
@@ -85,7 +92,7 @@ TILT_FEATURES = (
     | CoverEntityFeature.SET_TILT_POSITION
 )
 
-LEGACY_FIELDS = TEMPLATE_ENTITY_LEGACY_FIELDS | {
+LEGACY_FIELDS = {
     CONF_VALUE_TEMPLATE: CONF_STATE,
     CONF_POSITION_TEMPLATE: CONF_POSITION,
     CONF_TILT_TEMPLATE: CONF_TILT,
@@ -93,26 +100,33 @@ LEGACY_FIELDS = TEMPLATE_ENTITY_LEGACY_FIELDS | {
 
 DEFAULT_NAME = "Template Cover"
 
-COVER_SCHEMA = vol.All(
+COVER_COMMON_SCHEMA = vol.Schema(
+    {
+        vol.Inclusive(CLOSE_ACTION, CONF_OPEN_AND_CLOSE): cv.SCRIPT_SCHEMA,
+        vol.Inclusive(OPEN_ACTION, CONF_OPEN_AND_CLOSE): cv.SCRIPT_SCHEMA,
+        vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
+        vol.Optional(CONF_POSITION): cv.template,
+        vol.Optional(CONF_STATE): cv.template,
+        vol.Optional(CONF_TILT): cv.template,
+        vol.Optional(POSITION_ACTION): cv.SCRIPT_SCHEMA,
+        vol.Optional(STOP_ACTION): cv.SCRIPT_SCHEMA,
+        vol.Optional(TILT_ACTION): cv.SCRIPT_SCHEMA,
+    }
+)
+
+COVER_YAML_SCHEMA = vol.All(
     vol.Schema(
         {
-            vol.Inclusive(CLOSE_ACTION, CONF_OPEN_AND_CLOSE): cv.SCRIPT_SCHEMA,
-            vol.Inclusive(OPEN_ACTION, CONF_OPEN_AND_CLOSE): cv.SCRIPT_SCHEMA,
-            vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
-            vol.Optional(CONF_OPTIMISTIC): cv.boolean,
-            vol.Optional(CONF_POSITION): cv.template,
-            vol.Optional(CONF_STATE): cv.template,
             vol.Optional(CONF_TILT_OPTIMISTIC): cv.boolean,
-            vol.Optional(CONF_TILT): cv.template,
-            vol.Optional(POSITION_ACTION): cv.SCRIPT_SCHEMA,
-            vol.Optional(STOP_ACTION): cv.SCRIPT_SCHEMA,
-            vol.Optional(TILT_ACTION): cv.SCRIPT_SCHEMA,
         }
-    ).extend(make_template_entity_common_modern_schema(DEFAULT_NAME).schema),
+    )
+    .extend(COVER_COMMON_SCHEMA.schema)
+    .extend(TEMPLATE_ENTITY_OPTIMISTIC_SCHEMA)
+    .extend(make_template_entity_common_modern_schema(DEFAULT_NAME).schema),
     cv.has_at_least_one_key(OPEN_ACTION, POSITION_ACTION),
 )
 
-LEGACY_COVER_SCHEMA = vol.All(
+COVER_LEGACY_YAML_SCHEMA = vol.All(
     cv.deprecated(CONF_ENTITY_ID),
     vol.Schema(
         {
@@ -123,7 +137,6 @@ LEGACY_COVER_SCHEMA = vol.All(
             vol.Optional(CONF_POSITION_TEMPLATE): cv.template,
             vol.Optional(CONF_TILT_TEMPLATE): cv.template,
             vol.Optional(CONF_DEVICE_CLASS): DEVICE_CLASSES_SCHEMA,
-            vol.Optional(CONF_OPTIMISTIC): cv.boolean,
             vol.Optional(CONF_TILT_OPTIMISTIC): cv.boolean,
             vol.Optional(POSITION_ACTION): cv.SCRIPT_SCHEMA,
             vol.Optional(TILT_ACTION): cv.SCRIPT_SCHEMA,
@@ -131,61 +144,20 @@ LEGACY_COVER_SCHEMA = vol.All(
             vol.Optional(CONF_ENTITY_ID): cv.entity_ids,
             vol.Optional(CONF_UNIQUE_ID): cv.string,
         }
-    ).extend(TEMPLATE_ENTITY_COMMON_SCHEMA_LEGACY.schema),
+    )
+    .extend(TEMPLATE_ENTITY_COMMON_SCHEMA_LEGACY.schema)
+    .extend(TEMPLATE_ENTITY_OPTIMISTIC_SCHEMA),
     cv.has_at_least_one_key(OPEN_ACTION, POSITION_ACTION),
 )
 
 PLATFORM_SCHEMA = COVER_PLATFORM_SCHEMA.extend(
-    {vol.Required(CONF_COVERS): cv.schema_with_slug_keys(LEGACY_COVER_SCHEMA)}
+    {vol.Required(CONF_COVERS): cv.schema_with_slug_keys(COVER_LEGACY_YAML_SCHEMA)}
 )
 
-
-def rewrite_legacy_to_modern_conf(
-    hass: HomeAssistant, config: dict[str, dict]
-) -> list[dict]:
-    """Rewrite legacy switch configuration definitions to modern ones."""
-    covers = []
-
-    for object_id, entity_conf in config.items():
-        entity_conf = {**entity_conf, CONF_OBJECT_ID: object_id}
-
-        entity_conf = rewrite_common_legacy_to_modern_conf(
-            hass, entity_conf, LEGACY_FIELDS
-        )
-
-        if CONF_NAME not in entity_conf:
-            entity_conf[CONF_NAME] = template.Template(object_id, hass)
-
-        covers.append(entity_conf)
-
-    return covers
-
-
-@callback
-def _async_create_template_tracking_entities(
-    async_add_entities: AddEntitiesCallback,
-    hass: HomeAssistant,
-    definitions: list[dict],
-    unique_id_prefix: str | None,
-) -> None:
-    """Create the template switches."""
-    covers = []
-
-    for entity_conf in definitions:
-        unique_id = entity_conf.get(CONF_UNIQUE_ID)
-
-        if unique_id and unique_id_prefix:
-            unique_id = f"{unique_id_prefix}-{unique_id}"
-
-        covers.append(
-            CoverTemplate(
-                hass,
-                entity_conf,
-                unique_id,
-            )
-        )
-
-    async_add_entities(covers)
+COVER_CONFIG_ENTRY_SCHEMA = vol.All(
+    COVER_COMMON_SCHEMA.extend(TEMPLATE_ENTITY_COMMON_CONFIG_ENTRY_SCHEMA.schema),
+    cv.has_at_least_one_key(OPEN_ACTION, POSITION_ACTION),
+)
 
 
 async def async_setup_platform(
@@ -195,47 +167,66 @@ async def async_setup_platform(
     discovery_info: DiscoveryInfoType | None = None,
 ) -> None:
     """Set up the Template cover."""
-    if discovery_info is None:
-        _async_create_template_tracking_entities(
-            async_add_entities,
-            hass,
-            rewrite_legacy_to_modern_conf(hass, config[CONF_COVERS]),
-            None,
-        )
-        return
-
-    if "coordinator" in discovery_info:
-        async_add_entities(
-            TriggerCoverEntity(hass, discovery_info["coordinator"], config)
-            for config in discovery_info["entities"]
-        )
-        return
-
-    _async_create_template_tracking_entities(
-        async_add_entities,
+    await async_setup_template_platform(
         hass,
-        discovery_info["entities"],
-        discovery_info["unique_id"],
+        COVER_DOMAIN,
+        config,
+        StateCoverEntity,
+        TriggerCoverEntity,
+        async_add_entities,
+        discovery_info,
+        LEGACY_FIELDS,
+        legacy_key=CONF_COVERS,
+    )
+
+
+async def async_setup_entry(
+    hass: HomeAssistant,
+    config_entry: ConfigEntry,
+    async_add_entities: AddConfigEntryEntitiesCallback,
+) -> None:
+    """Initialize config entry."""
+    await async_setup_template_entry(
+        hass,
+        config_entry,
+        async_add_entities,
+        StateCoverEntity,
+        COVER_CONFIG_ENTRY_SCHEMA,
+        True,
+    )
+
+
+@callback
+def async_create_preview_cover(
+    hass: HomeAssistant, name: str, config: dict[str, Any]
+) -> StateCoverEntity:
+    """Create a preview."""
+    return async_setup_template_preview(
+        hass,
+        name,
+        config,
+        StateCoverEntity,
+        COVER_CONFIG_ENTRY_SCHEMA,
+        True,
     )
 
 
 class AbstractTemplateCover(AbstractTemplateEntity, CoverEntity):
     """Representation of a template cover features."""
 
+    _entity_id_format = ENTITY_ID_FORMAT
+    _optimistic_entity = True
+    _extra_optimistic_options = (CONF_POSITION,)
+
     # The super init is not called because TemplateEntity and TriggerEntity will call AbstractTemplateEntity.__init__.
     # This ensures that the __init__ on AbstractTemplateEntity is not called twice.
     def __init__(self, config: dict[str, Any]) -> None:  # pylint: disable=super-init-not-called
         """Initialize the features."""
 
-        self._template = config.get(CONF_STATE)
         self._position_template = config.get(CONF_POSITION)
         self._tilt_template = config.get(CONF_TILT)
         self._attr_device_class = config.get(CONF_DEVICE_CLASS)
 
-        optimistic = config.get(CONF_OPTIMISTIC)
-        self._optimistic = optimistic or (
-            optimistic is None and not self._template and not self._position_template
-        )
         tilt_optimistic = config.get(CONF_TILT_OPTIMISTIC)
         self._tilt_optimistic = tilt_optimistic or not self._tilt_template
         self._position: int | None = None
@@ -377,7 +368,7 @@ class AbstractTemplateCover(AbstractTemplateEntity, CoverEntity):
                 run_variables={"position": 100},
                 context=self._context,
             )
-        if self._optimistic:
+        if self._attr_assumed_state:
             self._position = 100
             self.async_write_ha_state()
 
@@ -391,7 +382,7 @@ class AbstractTemplateCover(AbstractTemplateEntity, CoverEntity):
                 run_variables={"position": 0},
                 context=self._context,
             )
-        if self._optimistic:
+        if self._attr_assumed_state:
             self._position = 0
             self.async_write_ha_state()
 
@@ -408,7 +399,7 @@ class AbstractTemplateCover(AbstractTemplateEntity, CoverEntity):
             run_variables={"position": self._position},
             context=self._context,
         )
-        if self._optimistic:
+        if self._attr_assumed_state:
             self.async_write_ha_state()
 
     async def async_open_cover_tilt(self, **kwargs: Any) -> None:
@@ -445,7 +436,7 @@ class AbstractTemplateCover(AbstractTemplateEntity, CoverEntity):
             self.async_write_ha_state()
 
 
-class CoverTemplate(TemplateEntity, AbstractTemplateCover):
+class StateCoverEntity(TemplateEntity, AbstractTemplateCover):
     """Representation of a Template cover."""
 
     _attr_should_poll = False
@@ -457,12 +448,8 @@ class CoverTemplate(TemplateEntity, AbstractTemplateCover):
         unique_id,
     ) -> None:
         """Initialize the Template cover."""
-        TemplateEntity.__init__(self, hass, config=config, unique_id=unique_id)
+        TemplateEntity.__init__(self, hass, config, unique_id)
         AbstractTemplateCover.__init__(self, config)
-        if (object_id := config.get(CONF_OBJECT_ID)) is not None:
-            self.entity_id = async_generate_entity_id(
-                ENTITY_ID_FORMAT, object_id, hass=hass
-            )
         name = self._attr_name
         if TYPE_CHECKING:
             assert name is not None
@@ -556,10 +543,9 @@ class TriggerCoverEntity(TriggerEntity, AbstractTemplateCover):
                 updater(rendered)
                 write_ha_state = True
 
-        if not self._optimistic:
-            self.async_set_context(self.coordinator.data["context"])
+        if not self._attr_assumed_state:
             write_ha_state = True
-        elif self._optimistic and len(self._rendered) > 0:
+        elif self._attr_assumed_state and len(self._rendered) > 0:
             # In case any non optimistic template
             write_ha_state = True
 
