@@ -1,21 +1,29 @@
 """Support for Vodafone Station."""
+
 from dataclasses import dataclass
 from datetime import datetime, timedelta
-from typing import Any
+from json.decoder import JSONDecodeError
+from typing import Any, cast
 
+from aiohttp import ClientSession
 from aiovodafone import VodafoneStationDevice, VodafoneStationSercommApi, exceptions
 
 from homeassistant.components.device_tracker import DEFAULT_CONSIDER_HOME
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 from homeassistant.exceptions import ConfigEntryAuthFailed
+from homeassistant.helpers import device_registry as dr
 from homeassistant.helpers.device_registry import DeviceInfo
 from homeassistant.helpers.update_coordinator import DataUpdateCoordinator, UpdateFailed
 from homeassistant.util import dt as dt_util
 
-from .const import _LOGGER, DOMAIN
+from .const import _LOGGER, DOMAIN, SCAN_INTERVAL
+from .helpers import cleanup_device_tracker
 
 CONSIDER_HOME_SECONDS = DEFAULT_CONSIDER_HOME.total_seconds()
 
+type VodafoneConfigEntry = ConfigEntry[VodafoneStationRouter]
+
 
 @dataclass(slots=True)
 class VodafoneStationDeviceInfo:
@@ -37,28 +45,43 @@ class UpdateCoordinatorDataType:
 class VodafoneStationRouter(DataUpdateCoordinator[UpdateCoordinatorDataType]):
     """Queries router running Vodafone Station firmware."""
 
+    config_entry: VodafoneConfigEntry
+
     def __init__(
         self,
         hass: HomeAssistant,
         host: str,
         username: str,
         password: str,
-        config_entry_unique_id: str | None,
+        config_entry: VodafoneConfigEntry,
+        session: ClientSession,
     ) -> None:
         """Initialize the scanner."""
 
         self._host = host
-        self.api = VodafoneStationSercommApi(host, username, password)
+        self.api = VodafoneStationSercommApi(host, username, password, session)
 
         # Last resort as no MAC or S/N can be retrieved via API
-        self._id = config_entry_unique_id
+        self._id = config_entry.unique_id
 
         super().__init__(
             hass=hass,
             logger=_LOGGER,
             name=f"{DOMAIN}-{host}-coordinator",
-            update_interval=timedelta(seconds=30),
+            update_interval=timedelta(seconds=SCAN_INTERVAL),
+            config_entry=config_entry,
         )
+        device_reg = dr.async_get(self.hass)
+        device_list = dr.async_entries_for_config_entry(
+            device_reg, self.config_entry.entry_id
+        )
+
+        self.previous_devices = {
+            connection[1].upper()
+            for device in device_list
+            for connection in device.connections
+            if connection[0] == dr.CONNECTION_NETWORK_MAC
+        }
 
     def _calculate_update_time_and_consider_home(
         self, device: VodafoneStationDevice, utc_point_in_time: datetime
@@ -94,23 +117,29 @@ class VodafoneStationRouter(DataUpdateCoordinator[UpdateCoordinatorDataType]):
     async def _async_update_data(self) -> UpdateCoordinatorDataType:
         """Update router data."""
         _LOGGER.debug("Polling Vodafone Station host: %s", self._host)
+
         try:
-            try:
-                await self.api.login()
-                raw_data_devices = await self.api.get_devices_data()
-                data_sensors = await self.api.get_sensor_data()
-                await self.api.logout()
-            except exceptions.CannotAuthenticate as err:
-                raise ConfigEntryAuthFailed from err
-            except (
-                exceptions.CannotConnect,
-                exceptions.AlreadyLogged,
-                exceptions.GenericLoginError,
-            ) as err:
-                raise UpdateFailed(f"Error fetching data: {repr(err)}") from err
-        except (ConfigEntryAuthFailed, UpdateFailed):
-            await self.api.close()
-            raise
+            await self.api.login()
+            raw_data_devices = await self.api.get_devices_data()
+            data_sensors = await self.api.get_sensor_data()
+            await self.api.logout()
+        except exceptions.CannotAuthenticate as err:
+            raise ConfigEntryAuthFailed(
+                translation_domain=DOMAIN,
+                translation_key="cannot_authenticate",
+                translation_placeholders={"error": repr(err)},
+            ) from err
+        except (
+            exceptions.CannotConnect,
+            exceptions.AlreadyLogged,
+            exceptions.GenericLoginError,
+            JSONDecodeError,
+        ) as err:
+            raise UpdateFailed(
+                translation_domain=DOMAIN,
+                translation_key="update_failed",
+                translation_placeholders={"error": repr(err)},
+            ) from err
 
         utc_point_in_time = dt_util.utcnow()
         data_devices = {
@@ -122,6 +151,18 @@ class VodafoneStationRouter(DataUpdateCoordinator[UpdateCoordinatorDataType]):
             )
             for dev_info in (raw_data_devices).values()
         }
+        current_devices = set(data_devices)
+        _LOGGER.debug(
+            "Loaded current %s devices: %s", len(current_devices), current_devices
+        )
+        if stale_devices := self.previous_devices - current_devices:
+            _LOGGER.debug(
+                "Found %s stale devices: %s", len(stale_devices), stale_devices
+            )
+            await cleanup_device_tracker(self.hass, self.config_entry, data_devices)
+
+        self.previous_devices = current_devices
+
         return UpdateCoordinatorDataType(data_devices, data_sensors)
 
     @property
@@ -132,7 +173,7 @@ class VodafoneStationRouter(DataUpdateCoordinator[UpdateCoordinatorDataType]):
     @property
     def serial_number(self) -> str:
         """Device serial number."""
-        return self.data.sensors["sys_serial_number"]
+        return cast(str, self.data.sensors["sys_serial_number"])
 
     @property
     def device_info(self) -> DeviceInfo:
