@@ -1,5 +1,9 @@
 """Jabber (XMPP) notification service."""
+
+from __future__ import annotations
+
 from concurrent.futures import TimeoutError as FutTimeoutError
+from http import HTTPStatus
 import logging
 import mimetypes
 import pathlib
@@ -20,7 +24,7 @@ import voluptuous as vol
 from homeassistant.components.notify import (
     ATTR_TITLE,
     ATTR_TITLE_DEFAULT,
-    PLATFORM_SCHEMA,
+    PLATFORM_SCHEMA as NOTIFY_PLATFORM_SCHEMA,
     BaseNotificationService,
 )
 from homeassistant.const import (
@@ -29,10 +33,10 @@ from homeassistant.const import (
     CONF_RESOURCE,
     CONF_ROOM,
     CONF_SENDER,
-    HTTP_BAD_REQUEST,
 )
-import homeassistant.helpers.config_validation as cv
-import homeassistant.helpers.template as template_helper
+from homeassistant.core import HomeAssistant
+from homeassistant.helpers import config_validation as cv, template as template_helper
+from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -51,7 +55,7 @@ DEFAULT_CONTENT_TYPE = "application/octet-stream"
 DEFAULT_RESOURCE = "home-assistant"
 XEP_0363_TIMEOUT = 10
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
+PLATFORM_SCHEMA = NOTIFY_PLATFORM_SCHEMA.extend(
     {
         vol.Required(CONF_SENDER): cv.string,
         vol.Required(CONF_PASSWORD): cv.string,
@@ -64,7 +68,11 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
 )
 
 
-async def async_get_service(hass, config, discovery_info=None):
+async def async_get_service(
+    hass: HomeAssistant,
+    config: ConfigType,
+    discovery_info: DiscoveryInfoType | None = None,
+) -> XmppNotificationService:
     """Get the Jabber (XMPP) notification service."""
     return XmppNotificationService(
         config.get(CONF_SENDER),
@@ -113,7 +121,7 @@ class XmppNotificationService(BaseNotificationService):
         )
 
 
-async def async_send_message(
+async def async_send_message(  # noqa: C901
     sender,
     password,
     recipients,
@@ -136,9 +144,10 @@ async def async_send_message(
 
             self.loop = hass.loop
 
-            self.force_starttls = use_tls
+            self.enable_starttls = use_tls
+            self.enable_direct_tls = use_tls
             self.use_ipv6 = False
-            self.add_event_handler("failed_auth", self.disconnect_on_login_fail)
+            self.add_event_handler("failed_all_auth", self.disconnect_on_login_fail)
             self.add_event_handler("session_start", self.start)
 
             if room:
@@ -155,17 +164,20 @@ async def async_send_message(
                 self.register_plugin("xep_0128")  # Service Discovery
                 self.register_plugin("xep_0363")  # HTTP upload
 
-            self.connect(force_starttls=self.force_starttls, use_ssl=False)
+            self.connect()
 
         async def start(self, event):
             """Start the communication and sends the message."""
+            if room:
+                _LOGGER.debug("Joining room %s", room)
+                await self.plugin["xep_0045"].join_muc_wait(room, sender, seconds=0)
             # Sending image and message independently from each other
             if data:
                 await self.send_file(timeout=timeout)
             if message:
                 self.send_text_message()
 
-            self.disconnect(wait=True)
+            self.disconnect()
 
         async def send_file(self, timeout=None):
             """Send file via XMPP.
@@ -173,21 +185,18 @@ async def async_send_message(
             Send XMPP file message using OOB (XEP_0066) and
             HTTP Upload (XEP_0363)
             """
-            if room:
-                self.plugin["xep_0045"].join_muc(room, sender, wait=True)
-
             try:
                 # Uploading with XEP_0363
                 _LOGGER.debug("Timeout set to %ss", timeout)
                 url = await self.upload_file(timeout=timeout)
 
-                _LOGGER.info("Upload success")
+                _LOGGER.debug("Upload success")
                 for recipient in recipients:
                     if room:
-                        _LOGGER.info("Sending file to %s", room)
+                        _LOGGER.debug("Sending file to %s", room)
                         message = self.Message(sto=room, stype="groupchat")
                     else:
-                        _LOGGER.info("Sending file to %s", recipient)
+                        _LOGGER.debug("Sending file to %s", recipient)
                         message = self.Message(sto=recipient, stype="chat")
                     message["body"] = url
                     message["oob"]["url"] = url
@@ -255,7 +264,7 @@ async def async_send_message(
 
             uploaded via XEP_0363 and HTTP and returns the resulting URL
             """
-            _LOGGER.info("Getting file from %s", url)
+            _LOGGER.debug("Getting file from %s", url)
 
             def get_url(url):
                 """Return result for GET request to url."""
@@ -265,7 +274,7 @@ async def async_send_message(
 
             result = await hass.async_add_executor_job(get_url, url)
 
-            if result.status_code >= HTTP_BAD_REQUEST:
+            if result.status_code >= HTTPStatus.BAD_REQUEST:
                 _LOGGER.error("Could not load file from %s", url)
                 return None
 
@@ -286,9 +295,9 @@ async def async_send_message(
                 _LOGGER.debug("Got %s extension", extension)
                 filename = self.get_random_filename(None, extension=extension)
 
-            _LOGGER.info("Uploading file from URL, %s", filename)
+            _LOGGER.debug("Uploading file from URL, %s", filename)
 
-            url = await self["xep_0363"].upload_file(
+            return await self["xep_0363"].upload_file(
                 filename,
                 size=filesize,
                 input_file=result.content,
@@ -296,23 +305,24 @@ async def async_send_message(
                 timeout=timeout,
             )
 
-            return url
+        def _read_upload_file(self, path: str) -> bytes:
+            """Read file from path."""
+            with open(path, "rb") as upfile:
+                _LOGGER.debug("Reading file %s", path)
+                return upfile.read()
 
-        async def upload_file_from_path(self, path, timeout=None):
+        async def upload_file_from_path(self, path: str, timeout=None):
             """Upload a file from a local file path via XEP_0363."""
-            _LOGGER.info("Uploading file from path, %s", path)
+            _LOGGER.debug("Uploading file from path, %s", path)
 
             if not hass.config.is_allowed_path(path):
                 raise PermissionError("Could not access file. Path not allowed")
 
-            with open(path, "rb") as upfile:
-                _LOGGER.debug("Reading file %s", path)
-                input_file = upfile.read()
+            input_file = await hass.async_add_executor_job(self._read_upload_file, path)
             filesize = len(input_file)
             _LOGGER.debug("Filesize is %s bytes", filesize)
 
-            content_type = mimetypes.guess_type(path)[0]
-            if content_type is None:
+            if (content_type := mimetypes.guess_type(path)[0]) is None:
                 content_type = DEFAULT_CONTENT_TYPE
             _LOGGER.debug("Content type is %s", content_type)
 
@@ -320,7 +330,7 @@ async def async_send_message(
             filename = self.get_random_filename(data.get(ATTR_PATH))
             _LOGGER.debug("Uploading file with random filename %s", filename)
 
-            url = await self["xep_0363"].upload_file(
+            return await self["xep_0363"].upload_file(
                 filename,
                 size=filesize,
                 input_file=input_file,
@@ -328,14 +338,11 @@ async def async_send_message(
                 timeout=timeout,
             )
 
-            return url
-
         def send_text_message(self):
             """Send a text only message to a room or a recipient."""
             try:
                 if room:
-                    _LOGGER.debug("Joining room %s", room)
-                    self.plugin["xep_0045"].join_muc(room, sender, wait=True)
+                    _LOGGER.debug("Sending message to room %s", room)
                     self.send_message(mto=room, mbody=message, mtype="groupchat")
                 else:
                     for recipient in recipients:
@@ -346,7 +353,6 @@ async def async_send_message(
             except NotConnectedError as ex:
                 _LOGGER.error("Connection error %s", ex)
 
-        # pylint: disable=no-self-use
         def get_random_filename(self, filename, extension=None):
             """Return a random filename, leaving the extension intact."""
             if extension is None:
@@ -368,6 +374,6 @@ async def async_send_message(
         @staticmethod
         def discard_ssl_invalid_cert(event):
             """Do nothing if ssl certificate is invalid."""
-            _LOGGER.info("Ignoring invalid SSL certificate as requested")
+            _LOGGER.debug("Ignoring invalid SSL certificate as requested")
 
     SendNotificationBot()
