@@ -135,6 +135,19 @@ async def test_show_form(manager: MockFlowManager) -> None:
 
 async def test_form_shows_with_added_suggested_values(manager: MockFlowManager) -> None:
     """Test that we can show a form with suggested values."""
+
+    def compare_schemas(schema: vol.Schema, expected_schema: vol.Schema) -> None:
+        """Compare two schemas."""
+        assert schema.schema is not expected_schema.schema
+
+        assert list(schema.schema) == list(expected_schema.schema)
+
+        for key, validator in schema.schema.items():
+            if isinstance(validator, data_entry_flow.section):
+                assert validator.schema == expected_schema.schema[key].schema
+                continue
+            assert validator == expected_schema.schema[key]
+
     schema = vol.Schema(
         {
             vol.Required("username"): str,
@@ -155,20 +168,25 @@ async def test_form_shows_with_added_suggested_values(manager: MockFlowManager)
         async def async_step_init(self, user_input=None):
             data_schema = self.add_suggested_values_to_schema(
                 schema,
-                {
-                    "username": "doej",
-                    "password": "verySecret1",
-                    "section_1": {"full_name": "John Doe"},
-                },
+                user_input,
             )
             return self.async_show_form(
                 step_id="init",
                 data_schema=data_schema,
             )
 
-    form = await manager.async_init("test")
+    form = await manager.async_init(
+        "test",
+        data={
+            "username": "doej",
+            "password": "verySecret1",
+            "section_1": {"full_name": "John Doe"},
+        },
+    )
     assert form["type"] == data_entry_flow.FlowResultType.FORM
-    assert form["data_schema"].schema == schema.schema
+    assert form["data_schema"].schema is not schema.schema
+    assert form["data_schema"].schema != schema.schema
+    compare_schemas(form["data_schema"], schema)
     markers = list(form["data_schema"].schema)
     assert len(markers) == 3
     assert markers[0] == "username"
@@ -178,15 +196,41 @@ async def test_form_shows_with_added_suggested_values(manager: MockFlowManager)
     assert markers[2] == "section_1"
     section_validator = form["data_schema"].schema["section_1"]
     assert isinstance(section_validator, data_entry_flow.section)
-    # The section class was not replaced
-    assert section_validator is schema.schema["section_1"]
-    # The section schema was not replaced
-    assert section_validator.schema is schema.schema["section_1"].schema
+    # The section instance was copied
+    assert section_validator is not schema.schema["section_1"]
+    # The section schema instance was copied
+    assert section_validator.schema is not schema.schema["section_1"].schema
+    assert section_validator.schema == schema.schema["section_1"].schema
     section_markers = list(section_validator.schema.schema)
     assert len(section_markers) == 1
     assert section_markers[0] == "full_name"
     assert section_markers[0].description == {"suggested_value": "John Doe"}
 
+    # Test again without suggested values to make sure we're not mutating the schema
+    form = await manager.async_init(
+        "test",
+    )
+    assert form["type"] == data_entry_flow.FlowResultType.FORM
+    assert form["data_schema"].schema is not schema.schema
+    assert form["data_schema"].schema == schema.schema
+    markers = list(form["data_schema"].schema)
+    assert len(markers) == 3
+    assert markers[0] == "username"
+    assert markers[0].description is None
+    assert markers[1] == "password"
+    assert markers[1].description is None
+    assert markers[2] == "section_1"
+    section_validator = form["data_schema"].schema["section_1"]
+    assert isinstance(section_validator, data_entry_flow.section)
+    # The section class is not replaced if there is no suggested value for the section
+    assert section_validator is schema.schema["section_1"]
+    # The section schema is not replaced if there is no suggested value for the section
+    assert section_validator.schema is schema.schema["section_1"].schema
+    section_markers = list(section_validator.schema.schema)
+    assert len(section_markers) == 1
+    assert section_markers[0] == "full_name"
+    assert section_markers[0].description is None
+
 
 async def test_abort_removes_instance(manager: MockFlowManager) -> None:
     """Test that abort removes the flow from progress."""
